*==============================================================================*
* TÍTULO DE LA SINTAXIS:													   *
* Lactancia materna						                                       *
* OPERACIÓN ESTADÍSTICA:													   *
* Encuesta Nacional de Salud y Nutrición (ENSANUT - 2018)					   *
*==============================================================================*
* Fecha de elaboración:        3  de Enero del 2018						       *
* Fecha última modificación:  19 de Diciembre del 2019				   	   	   *
*==============================================================================*
* Elaborado por:                                                               *
* Instituto Nacional de Estadística y Censos (INEC)							   *
* Link:                                                                        *
* www.ecuadorencifras.gob.ec 												   *
*==============================================================================*

clear all
set more off
*En esta sección se copia la dirección en donde se encuentran las bases de datos
cd "C:\ENSANUT 2018\Bases de datos\Bases_trabajadas"

use 1_BDD_ENS2018_f1_personas, clear 
rename id_per id_hijo
keep id_hijo f1_s2_4_2 f1_s2_4_1 f1_s2_4_3
tempfile base_per
save `base_per', replace

use 5_BDD_ENS2018_f2_lactancia, clear 

merge m:1 id_hijo using `base_per'
keep if _merge==3 | _merge==1 
drop _merge

svyset upm [iw=fexp], strata(estrato) vce(linearized) singleunit(certainty) 

*==============================================================================*
* Generación de variables para el cáculo de los indicadores
*==============================================================================*
*** 1.- Estimación de la edad (días)
cap drop edaddias
* Fecha de nacimiento
gen dob=mdy(f1_s2_4_2,f1_s2_4_1,f1_s2_4_3)
* Fecha de visita
gen dov=mdy(fecha_mes,fecha_dia,fecha_anio)
* Edad en días
gen edaddias= dov-dob

*==============================================================================*
* T10_i1_1. Inicio temprano de la lactancia materna menor de 1 año
*==============================================================================*

gen  	kids_12_24 = 2 if (edaddias <731)
replace kids_12_24 = 1 if (edaddias <365)
label variable kids_12_24 "Niños nacidos 12 24"

gen 	it_lacm = f2_s3a_304
replace it_lacm=1 if it_lacm==2
label value it_lacm f2_s3a_304

tab it_lacm if kids_12_24==1
tab it_lacm 

***
cap drop it_lacm_1
gen it_lacm_1=.
replace it_lacm_1=0 if it_lacm!=. & kids_12_24==1 
replace it_lacm_1=0 if f2_s3a_302==2 & kids_12_24==1    
replace it_lacm_1=100 if it_lacm==1 & kids_12_24==1
tab it_lacm_1 

*==============================================================================*
* T10_i1_2. Inicio temprano de la lactancia materna menor de 2 año
*==============================================================================*

cap drop it_lacm_2
gen it_lacm_2=.
replace it_lacm_2=0 if it_lacm!=. & kids_12_24==2 
replace it_lacm_2=0 if f2_s3a_302==2 & kids_12_24==2   
replace it_lacm_2=100 if it_lacm==1 & kids_12_24==2
tab it_lacm_2 
***

*==============================================================================*
* T10_i2. Lactancia materna exclusiva en los 6 primeros meses
*==============================================================================*
cap drop lac_exc6
gen 	lac_exc6 = 100 if (edaddias!= . & edaddias<183 & f2_s3b_305==1 & f2_s3d_310==2 & f2_s3d_312==2)
replace lac_exc6 = 0 if (edaddias!= . & edaddias<183 & f2_s3b_305 !=. & f2_s3d_310 !=. & f2_s3d_312 !=. & lac_exc6==.)
label variable lac_exc6 "Lactantes de cero a 6 mes de edad que recibieron solamente leche materna el día anterior"

tab lac_exc6

*==============================================================================*
* T10_i3. Lactancia materna continua
*==============================================================================*
gen 	lac_cont = 100 if (edaddias>=365 & edaddias<487) & (f2_s3c_308==1)
replace lac_cont = 0 if (edaddias>=365 & edaddias<487 & f2_s3c_308<=2 & lac_cont==.)
label variable lac_cont "Niños de 12 a 15 meses de edad que fueron amamantados durante el día anterior"

tab lac_cont

rename 	it_lacm_1	T10_i1_1
rename 	it_lacm_2	T10_i1_2
rename 	lac_exc6	T10_i2
rename 	lac_cont	T10_i3




