*==============================================================================*
* TÍTULO DE LA SINTAXIS:													   *
* Alimentación complementaria			                    				   *
* OPERACIÓN ESTADÍSTICA:													   *
* Encuesta Nacional de Salud y Nutrición (ENSANUT - 2018)					   *
*==============================================================================*
* Fecha de elaboración:        3  de Enero del 2018						       *
* Fecha última modificación:  19 de Diciembre del 2019				   	   	   *
*==============================================================================*
* Elaborado por:                                                               *
* Instituto Nacional de Estadística y Censos (INEC)							   *
* Link:                                                                        *
* www.ecuadorencifras.gob.ec 												   *
*==============================================================================*

clear all
set more off
*En esta sección se copia la dirección en donde se encuentran las bases de datos
cd "C:\ENSANUT 2018\Bases de datos\Bases_trabajadas"

use 1_BDD_ENS2018_f1_personas, clear 
rename id_per id_hijo
keep id_hijo f1_s2_4_2 f1_s2_4_1 f1_s2_4_3
tempfile base_per
save `base_per', replace

use 5_BDD_ENS2018_f2_lactancia, clear 

merge m:1 id_hijo using `base_per'
keep if _merge==3
drop _merge

svyset upm [iw=fexp], strata(estrato) vce(linearized) singleunit(certainty) 

*==============================================================================*
* Generación de variables para el cáculo de los indicadores
*==============================================================================*

*** 1.- Estimación de la edad (días)
cap drop edaddias
* Fecha de nacimiento
gen dob=mdy(f1_s2_4_2,f1_s2_4_1,f1_s2_4_3)
* Fecha de visita
gen dov=mdy(fecha_mes,fecha_dia,fecha_anio)
* Edad en días
gen edaddias= dov-dob

*==============================================================================*
* T11_i1. Diversidad alimentaria mínima
*==============================================================================*

* Denominador
gen 	ninos6_26 = 1 if (edaddias>=183 & edaddias<=730) & (f2_s3c_308<=2)
label 	variable ninos6_26 "Niños de 6 a 23 meses de edad"

*** Grupos de alimentos:
** Grupo 1:
gen		grupo1 = 1 if (f2_s3d_313_1==1 | f2_s3d_313_2==1 | f2_s3d_313_4==1)
replace grupo1 = 0 if (ninos6_26==1 & grupo1==.)
label variable grupo1 "cereales, raíces y tubérculos"
** Grupo 2:
gen 	grupo2 = 1 if (f2_s3d_313_12==1)
replace grupo2 = 0 if (ninos6_26==1 & grupo2==.)
label variable grupo2 "legumbres y nueces"
** Grupo 3:
gen 	grupo3 = 1 if (f2_s3d_313_13==1)
replace grupo3 = 0 if (ninos6_26==1 & grupo3==.)
label variable grupo3 "lácteos (leche, yogurt, queso)"
** Grupo 4:
gen 	grupo4 = 1 if (f2_s3d_313_8==1 | f2_s3d_313_9==1 | f2_s3d_313_11==1)
replace grupo4 = 0 if (ninos6_26==1 & grupo4==.)
label variable grupo4 "carnes (carne, pescado, aves e hígado o carnes provenientes de vísceras)"
** Grupo 5:
gen 	grupo5 = 1 if (f2_s3d_313_10==1)
replace grupo5 = 0 if (ninos6_26==1 & grupo5==.)
label variable grupo5 "huevos"
** Grupo 6:
gen 	grupo6 = 1 if (f2_s3d_313_3==1 | f2_s3d_313_5==1 | f2_s3d_313_6==1)
replace grupo6 = 0 if (ninos6_26==1 & grupo6==.)
label variable grupo6 "frutas y verduras ricas en vitamina A"
** Grupo 7:
gen 	grupo7 = 1 if (f2_s3d_313_7==1)
replace grupo7 = 0 if (ninos6_26==1 & grupo7==.)
label variable grupo7 "otras frutas y verduras"

* Suma de la diversidad de alimentos:
gen 	div_grupos =(grupo1+grupo2+grupo3+grupo4+grupo5+grupo6+grupo7)
label 	variable div_grupos "Suma de todos los grupos"

* Niños amamantados de 6 a 23 meses de edad que recibieron alimentos
* de 4 y más grupos alimentarios durante el día anterior
gen 	divam6_23 = 100 if (edaddias>=183 & edaddias<=730 & f2_s3c_308==1 &  div_grupos>=4)
replace divam6_23 = 0 if (edaddias>=183 & edaddias<=730 & f2_s3c_308==1 & divam6_23==.)
label variable divam6_23 "Niños amamantados de 6 a 23 meses de edad que recibieron alimentos de >=4 grupos alimentarios durante el día anterior"
  
tab divam6_23

rename divam6_23 T11_i1
