*==============================================================================*
* TÍTULO DE LA SINTAXIS:													   *
* Salud en la niñez															   *
* OPERACIÓN ESTADÍSTICA:													   *
* Encuesta Nacional de Salud y Nutrición (ENSANUT - 2018)					   *
*==============================================================================*
* Fecha de elaboración:        3  de Enero del 2018						       *
* Fecha última modificación:  19 de Diciembre del 2019				   	   	   *
*==============================================================================*
* Elaborado por:                                                               *
* Instituto Nacional de Estadística y Censos (INEC)							   *
* Link:                                                                        *
* www.ecuadorencifras.gob.ec 												   *
*==============================================================================*

clear all
set more off

cd "C:\ENSANUT 2018\Bases de datos\Bases_trabajadas"

use 4_BDD_ENS2018_f2_mef, clear 

keep id* f2_s2_218_*_1 f2_s2_218_*_b* 

rename f2_s2_218_*_1 f2_s2_218_1_* 
rename f2_s2_218_*_b1 f2_s2_218_b1_*  
rename f2_s2_218_*_b2 f2_s2_218_b2_*  
rename f2_s2_218_*_b3 f2_s2_218_b3_* 

gen id_ma = _n
reshape long f2_s2_218_1_ ///
f2_s2_218_b1_ f2_s2_218_b2_ f2_s2_218_b3_ , i(id_ma) j(id_nin) 

*==============================================================================*
* Generación del identificador del hijo
*==============================================================================*
qui foreach var of varlist f2_s2_218_1_{
tempvar largo
tostring `var', replace force
gen `largo'=length(`var')
sum `largo'
replace `var'=substr(string(10^(r(max)-`largo')),2,.)+`var' if r(max)>`largo'
drop `largo'
}
*
egen id_hijo    =concat(id_hogar f2_s2_218_1_)
egen id_hijo_ord=concat(id_per f2_s2_218_1_ id_nin)
label var id_hijo "Identificador del hijo"
label var id_hijo_ord "Identificador del hijo según el orden"

*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
* Se valida los códigos de los hijos  
replace id_hijo_ord = "" if f2_s2_218_1_=="0." | f2_s2_218_1_=="00" 
*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

*Mantengo la base de los hijos 
keep if id_hijo_ord!=""

keep id_hijo id_hijo_ord f2_s2_218_b1_ f2_s2_218_b2_ f2_s2_218_b3_ 

tempfile base_f2_nac
save `base_f2_nac', replace

use 6_BDD_ENS2018_f2_salud_ninez, clear 

merge 1:1 id_hijo_ord using `base_f2_nac'
keep if _merge==3 | _merge==1
drop _merge

svyset upm [iw=fexp], strata(estrato) vce(linearized) singleunit(certainty) 

*------------------------------------------------------------------------------*
* Edad en días
*------------------------------------------------------------------------------*

***Fecha de nacimiento en días
gen f_nac=mdy(f2_s2_218_b2_,f2_s2_218_b1_,f2_s2_218_b3_)

***Fecha de visita
gen f_entre=mdy(fecha_mes,fecha_dia,fecha_anio)
   
***Edad en días 
gen edaddias= f_entre-f_nac

*------------------------------------------------------------------------------*
* Edad en días cuando se realizó la vacunación 
*------------------------------------------------------------------------------*
   
***Fecha de vacunación en días 
forval y = 1/15{
replace f2_s4j_487`y'aanio_ = f2_s4j_487`y'aanio_ + 2000 if f2_s4j_487`y'aanio_ !=.  
gen f_vac_`y'=mdy(f2_s4j_487`y'ames_,f2_s4j_487`y'adia_,f2_s4j_487`y'aanio_)
}
*

*Edad en días 
 forval y = 1/15{
 gen edaddias_vac_`y' = f_vac_`y' - f_nac  
}
*
*------------------------------------------------------------------------------*
* T12_i1. Porcentaje de niños menores de 2 y 5 años, cuyas madres recibieron al 
			*menos 5 controles prenatales durante el embarazo 
*------------------------------------------------------------------------------*

gen f2_s4b_421_1 = f2_s4b_421_ 
replace f2_s4b_421_1 = 0 if f2_s4b_406_ != . & f2_s4b_421_1==. 

gen     T12_i1_1 = 100 if f2_s4b_421_1 >= 5 & f2_s4b_421_1!=88  & edadmeses <= 59
replace T12_i1_1 = 0   if T12_i1_1 ==. & f2_s4b_406_ !=. & edadmeses <= 59
tab T12_i1_1 

gen     T12_i1_2 = 100 if f2_s4b_421_1 >= 5 & f2_s4b_421_1!=88 & edadmeses <= 23
replace T12_i1_2 = 0   if T12_i1_2 ==. & f2_s4b_406_ != . & edadmeses <= 23
tab T12_i1_2 

*------------------------------------------------------------------------------*
* T12_i2. Porcentaje de mujeres que recibieron control 
* 			post parto antes de los siete días
*------------------------------------------------------------------------------*

cap drop dias_control_post_parto T12_i2
gen dias_control_post_parto = f2_s4e_441a_ + f2_s4e_441b_*7 ///
	                          + f2_s4e_441c_*30.44
summ f2_s4e_440_
summ dias_control_post_parto

gen     T12_i2 = 100 if dias_control_post_parto < 7
replace T12_i2 = 0   if T12_i2 ==. & f2_s4e_440_ != .
tab T12_i2

*------------------------------------------------------------------------------*
* T12_i3. Inscripción de nacidos vivos en Registro Civil 
*------------------------------------------------------------------------------*

cap drop T12_i3
gen     T12_i3 = 100 if f2_s4f_445_==1 
replace T12_i3 = 0   if T12_i3 ==. & f2_s4f_445_ != . & f2_s4f_445_!=88   
tab T12_i3

*------------------------------------------------------------------------------*
* T12_i4. Prevalencia de diarrea 
*------------------------------------------------------------------------------*

cap drop T12_i4 
gen     T12_i4 = 0   if f2_s4g_457_ !=. & f2_s4g_457_!=88  
replace T12_i4 = 100 if f2_s4g_457_ ==1 
tab T12_i4

*------------------------------------------------------------------------------*
* T12_i5. Prevalencia de infecciones respiratorias agudas 
*------------------------------------------------------------------------------*

gen     T12_i5 = 0   if f2_s4h_473_!=. 
replace T12_i5 = 100 if f2_s4h_473_==1 
tab T12_i5 

*------------------------------------------------------------------------------*
* T12_i6. Vacunación 
*------------------------------------------------------------------------------*

***BCG 
gen     bcg =0   if (edaddias >= 365 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
replace bcg =100 if (f2_s4j_4871a1_ ==1 | f2_s4j_4871b1_ ==1)  & (edaddias >= 365 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
tab bcg 

***Hepatitis B
gen     hb =0   if (edaddias >= 2 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
replace hb =100 if (f2_s4j_4872a1_ ==1 | f2_s4j_4872b1_==1) & (edaddias >= 2 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
tab hb 

***Rotavirus 1
gen     rota1 =0   if  (edaddias >= 91 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
replace rota1 =100 if (f2_s4j_4873a1_ ==1 | f2_s4j_4873b1_==1)  & (edaddias >= 91 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
tab rota1

***Rotavirus 2
gen     rota2 =0   if  (edaddias >= 244 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
replace rota2 =100 if (f2_s4j_4874a1_ ==1 | f2_s4j_4874b1_==1)  & (edaddias >= 244 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
tab rota2

***Pentavalente 1 
gen     penta1 =0   if (edaddias >= 91 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
replace penta1 =100 if (f2_s4j_4875a1_ ==1 | f2_s4j_4875b1_==1) & (edaddias >= 91 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
tab penta1 

***Pentavalente 2
gen     penta2 =0   if (edaddias >= 152 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
replace penta2 =100 if (f2_s4j_4876a1_ ==1 | f2_s4j_4876b1_==1) & (edaddias >= 152 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
tab penta2 

***Pentavalente 3
gen     penta3 =0   if  (edaddias >= 213 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
replace penta3 =100 if (f2_s4j_4877a1_ ==1 | f2_s4j_4877b1_==1)  & (edaddias >= 213 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
tab penta3 

***IPV 1 
gen     ipv1 =0   if  (edaddias >= 91 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
replace ipv1 =100 if (f2_s4j_4878a1_ ==1 | f2_s4j_4878b1_==1)  & (edaddias >= 91 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
tab ipv1  

***OPV 2 
gen     opv2 =0   if  (edaddias >= 152 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
replace opv2 =100 if (f2_s4j_4879a1_ ==1 | f2_s4j_4879b1_==1)  & (edaddias >= 152 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
tab opv2  

***OPV 3
gen     opv3 =0   if  (edaddias >= 213 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
replace opv3 =100 if (f2_s4j_48710a1_ ==1 | f2_s4j_48710b1_==1)  & (edaddias >= 213 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
tab opv3 

***Neumococo CJ 1 
gen     neumo1 =0   if  (edaddias >= 91 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
replace neumo1 =100 if (f2_s4j_48711a1_ ==1 | f2_s4j_48711b1_==1) & (edaddias >= 91 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
tab neumo1 

***Neumococo CJ 2
gen     neumo2 =0   if  (edaddias >= 152 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
replace neumo2 =100 if (f2_s4j_48712a1_ ==1 | f2_s4j_48712b1_==1)  & (edaddias >= 152 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
tab neumo2 

***Neumococo CJ 3
gen     neumo3 =0   if  (edaddias >= 213 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)  
replace neumo3 =100 if (f2_s4j_48713a1_ ==1 | f2_s4j_48713b1_==1)  & (edaddias >= 213 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
tab neumo3

***SRP 1 
gen     srp1 =0   if  (edaddias >= 396 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3) 
replace srp1 =100 if (f2_s4j_48714a1_ ==1 | f2_s4j_48714b1_==1)  & (edaddias >= 396 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
tab srp1

***SRP 2
gen     srp2 =0   if  (edaddias >= 578 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)   
replace srp2 =100 if (f2_s4j_48715a1_ ==1 | f2_s4j_48715b1_==1) & (edaddias >= 578 & edaddias < 1826) & (f2_s4d_432_>=1 & f2_s4d_432_<=3)
tab srp2

rename 	bcg	    T12_i6_1
rename 	hb	    T12_i6_2
rename 	rota2	T12_i6_3
rename 	penta3	T12_i6_4
rename 	opv3	T12_i6_5
rename 	neumo3	T12_i6_6
rename 	srp2	T12_i6_7

*------------------------------------------------------------------------------*
* T12_i7. Promedio de controles del niño sano
*------------------------------------------------------------------------------*
	
*** Calculo
gen temp_miss = 0
foreach x of varlist f2_s4f_451c_1 f2_s4f_451b_1 f2_s4f_451a_1{
replace temp_miss = temp_miss+1 if `x' == .
}
egen controles_auto_reportado = rsum(f2_s4f_451c_1 f2_s4f_451b_1 ///
f2_s4f_451a_1) if temp_miss==0 & (inlist(f2_s4f_451a_1,77,88,99)==0) ///
& (inlist(f2_s4f_451b_1,77,88,99)==0) & (inlist(f2_s4f_451c_1,77,88,99)==0)

gen T12_i7_1 = controles_auto_reportado
label var T12_i7_1 "Controles a niño sano (Autoreportado)"

svy: mean T12_i7_1


*------------------------------------------------------------------------------*

