*==============================================================================*
* TÍTULO DE LA SINTAXIS:													   *
* Servicios asociados a la salud materna									   *
* OPERACIÓN ESTADÍSTICA:													   *
* Encuesta Nacional de Salud y Nutrición (ENSANUT - 2018)					   *
*==============================================================================*
* Fecha de elaboración:        3  de Enero del 2018						       *
* Fecha última modificación:  19 de Diciembre del 2019				   	   	   *
*==============================================================================*
* Elaborado por:                                                               *
* Instituto Nacional de Estadística y Censos (INEC)							   *
* Link:                                                                        *
* www.ecuadorencifras.gob.ec 												   *
*==============================================================================*

clear all
set more off
* En esta sección se copia la dirección en donde se encuentran las bases de datos
cd "C:\ENSANUT 2018\Bases de datos\Bases_trabajadas"

use 4_BDD_ENS2018_f2_mef, clear 

svyset upm [iw=fexp], strata(estrato) vce(linearized) singleunit(certainty) 

*==============================================================================*
* Preparación de la base de datos
*==============================================================================*
*** Edad en quinquenios de las MEF

recode f2_s1_101 (10/14=1 "10-14") (15/19=2 "15-19") (20/24=3 "20-24") ///
(25/29=4 "25-29") (30/34=5 "30-34") (35/39=6 "35-39") (40/44=7 "40-44") ///
(45/49=8 "45-49") (mis=.), gen(gr_ed)
lab var gr_ed "Grupos de edad por quiquenios"

*** Mujeres con experiencia sexual
* Experiencia sexual: Código 2 si no desea responder
cap drop exp_s
cap label drop exp_s
gen 	exp_s=f2_s8_803 if f2_s8_803<3
replace exp_s=1 if (gr_ed>=4 & f2_s8_803==.)
replace exp_s=2 if (gr_ed>=4 & f2_s8_831==99)
replace exp_s=3 if (gr_ed>=4 & f2_s8_831==77)
lab def exp_s 1 "Con experiencia sexual" 2 "Sin experiencia sexual" 3 "No contesta" 
lab val exp_s exp_s
lab var exp_s "Experiencia sexual"

tab exp_s

*==============================================================================*
* T13_i1. Realización de citología cérvicovaginal (papanicolau) 
*==============================================================================*

gen     papa=0   if f2_s5_527!=. & f2_s5_527!=88 & f2_s1_101>=12 & f2_s1_101!=. 
replace papa=100 if f2_s5_527==1 & f2_s1_101>=12 & f2_s1_101!=.
label var papa "Realización de citología cérvicovaginal (papanicolau)"
rename papa T13_i1 

*==============================================================================*
* T13_i2. Realización de mamografía
*==============================================================================*

cap drop mamo
cap label drop mamo
gen 	mamo=0   if f2_s5_536!=. & f2_s5_536!=77 & f2_s1_101>=24 & f2_s1_101!=. 
replace mamo=100 if f2_s5_536==1 & f2_s1_101>=24 & f2_s1_101!=. 
lab var mamo "Realización de mamografías para mujer mayores de 24 años" 
rename mamo T13_i2

*==============================================================================*
* T13_i6. Porcentaje de mujeres vacunadas contra el tetanos
*==============================================================================*

cap drop T13_i6
cap label drop T13_i6
gen 	T13_i6=0   if f2_s5_524!=. & f2_s1_101>=12 & f2_s1_101!=.
replace T13_i6=100 if f2_s5_524==1 & f2_s1_101>=12 & f2_s1_101!=.
lab var T13_i6 "Porcentaje de mujeres vacunadas contra el tetanos" 

