*==============================================================================*
* TÍTULO DE LA SINTAXIS:													   *
* Servicios asociados a la salud materna									   *
* OPERACIÓN ESTADÍSTICA:													   *
* Encuesta Nacional de Salud y Nutrición (ENSANUT - 2018)					   *
*==============================================================================*
* Fecha de elaboración:        3  de Enero del 2018						       *
* Fecha última modificación:  19 de Diciembre del 2019				   	   	   *
*==============================================================================*
* Elaborado por:                                                               *
* Instituto Nacional de Estadística y Censos (INEC)							   *
* Link:                                                                        *
* www.ecuadorencifras.gob.ec 												   *
*==============================================================================*

clear all
set more off
*En esta sección se copia la dirección en donde se encuentran las bases de datos
cd "C:\ENSANUT 2018\Bases de datos\Bases_trabajadas"

use 4_BDD_ENS2018_f2_mef, clear 
keep id_per f2_s1_101
tempfile base_mef
save `base_mef', replace 

use 1_BDD_ENS2018_f1_personas, clear 
rename id_per id_hijo
keep id_hijo f1_s2_4_2 f1_s2_4_1 f1_s2_4_3 
tempfile base_per
save `base_per', replace

use 6_BDD_ENS2018_f2_salud_ninez, clear 
  
merge m:1 id_hijo using `base_per'
keep if _merge==3 | _merge==1
drop _merge  

merge m:1 id_per using `base_mef'
keep if _merge==3 | _merge==1
drop _merge  

svyset upm [iw=fexp], strata(estrato) vce(linearized) singleunit(certainty) 

*==============================================================================*
* T13_i3. Porcentaje de nacimientos institucionales 
*==============================================================================*

gen partoinst=0 if f2_s4c_423a_!=. & f2_s1_101>=12 & f2_s1_101!=.
replace partoinst=100 if (f2_s4c_423a_>=1 & f2_s4c_423a_<=8) & f2_s1_101>=12 & f2_s1_101!=.     
lab var partoinst "Parto institucional"
rename partoinst T13_i3 

*==============================================================================*
* T13_i4. Porcentaje de nacimientos atendidos  por personal de salud calificado
*==============================================================================*

recode f2_s4c_424a_ (1/3=100 "Personal médico") (4/8=0 "Personal no médico") (nonmiss=.), gen(T13_i4)
lab var T13_i4 "Profesional médico que atendió el parto"

tab T13_i4

*==============================================================================*
* T13_i5. Porcentaje de mujeres que tuvieron parto por cesárea
*==============================================================================*

cap drop cesarea
cap label drop cesarea
gen 	cesarea=0   if f2_s4c_425_!=.
replace cesarea=100 if f2_s4c_425_==2
lab var cesarea "Porcentaje de mujeres que tuvieron parto por cesárea" 
tab cesarea

rename cesarea T13_i5

*==============================================================================*
* T13_i7. Porcentaje de bajo peso al nacer
*==============================================================================*

gen bajo_peso=0 if f2_s4d_436a_==1 
replace bajo_peso=100 if f2_s4d_436a_==1 & f2_s4d_436b_<=2500 
rename bajo_peso T13_i7

*==============================================================================*
