*==============================================================================*
* TÍTULO DE LA SINTAXIS:													   *
* Planificación Familiar													   *
* OPERACIÓN ESTADÍSTICA:													   *
* Encuesta Nacional de Salud y Nutrición (ENSANUT - 2018)					   *
*==============================================================================*
* Fecha de elaboración:        3 de Enero del 2018						       *
* Fecha última modificación:  19 de Diciembre del 2019				   	   	   *
*==============================================================================*
* Elaborado por:                                                               *
* Instituto Nacional de Estadística y Censos (INEC)							   *
* Link:                                                                        *
* www.ecuadorencifras.gob.ec 												   *
*==============================================================================*

clear all
set more off
* En esta sección se copia la dirección en donde se encuentran las bases de datos
cd "C:\ENSANUT 2018\Bases de datos\Bases_trabajadas"

use 7_BDD_ENS2018_f3_ssrh, clear 

svyset upm [iw=fexp], strata(estrato) vce(linearized) singleunit(certainty) 

*==============================================================================*
* T14_i4. Hombres que usaron métodos anticonceptivos 
*==============================================================================*

gen x=1 if (f3_s3_304_1==1 | f3_s3_304_2==1 | f3_s3_304_3==1 | f3_s3_304_4==1 | f3_s3_304_5==1 | f3_s3_304_6==1 | ///
f3_s3_304_7==1 | f3_s3_304_8==1 | f3_s3_304_9==1 | f3_s3_304_10==1 | f3_s3_304_11==1 | f3_s3_304_12==1 )

cap drop humm
gen 	humm=0   if f3_s1_2>=15 & f3_s1_2<=49 & x==1
replace humm=100 if (f3_s3_304_1==1 | f3_s3_304_2==1 | f3_s3_304_3==1 | f3_s3_304_4==1 | f3_s3_304_5==1 | f3_s3_304_6==1 | ///
f3_s3_304_7==1 | f3_s3_304_8==1 | f3_s3_304_9==1) & f3_s1_2>=15 & f3_s1_2<=49
tab humm

rename humm T14_i4 


*==============================================================================*
* T14_i5. Hombres que utilizan métodos anticonceptivos modernos actualmente
*==============================================================================*

gen y=1 if (f3_s3_305_1==1 | f3_s3_305_2==1 | f3_s3_305_3==1 | f3_s3_305_4==1 | f3_s3_305_5==1 | f3_s3_305_6==1 | ///
f3_s3_305_7==1 | f3_s3_305_8==1 | f3_s3_305_9==1 | f3_s3_305_10==1 | f3_s3_305_11==1 | f3_s3_305_12==1 )

gen 	umm=0   if f3_s1_2>=15 & f3_s1_2<=49 & y==1
replace umm=100 if (f3_s3_305_1==1 | f3_s3_305_2==1 | f3_s3_305_3==1 | f3_s3_305_4==1 | f3_s3_305_5==1 | f3_s3_305_6==1 | ///
f3_s3_305_7==1 | f3_s3_305_8==1 | f3_s3_305_9==1 ) & f3_s1_2>=15 & f3_s1_2<=49
rename umm T14_i5
tab T14_i5 


*==============================================================================*
* T14_i6. Edad promedio a la primera relación sexual de hombres
*==============================================================================* 

gen edad_pprs1 = f3_s2_203 if f3_s2_202==1 & f3_s2_203!=88 & f3_s2_203!=99 & inrange(f3_s1_2,15,24)
mean edad_pprs1 

rename edad_pprs1  T14_i6

*==============================================================================*
* T14_i8. Conocimiento de metodos de planificación hombres
*==============================================================================*

foreach x in 1 2 3 4 5 6 7 8 9 10 11 12 {
gen conoce_`x'=1 if f3_s3_302_`x'==1 | f3_s3_303_`x'==1 
}  
*
egen conoce = rowtotal(conoce_*) 

gen     T14_i8=0   if conoce!=.
replace T14_i8=100 if conoce>=1  

tab T14_i8 

*==============================================================================*
* T14_i9. Uso de métodos anticonceptivos en la primera relación sexual
*==============================================================================*

cap drop uaprs
cap label drop uaprs 
gen 	uaprs = 0   if inrange(f3_s1_2,15,24) & f3_s2_204!=.
replace uaprs = 100 if inrange(f3_s1_2,15,24) & f3_s2_204==1
lab var uaprs "Porcentaje de hombres entre 15 y 24 años que usaron métodos anticonceptivos en su primera relación sexual"
tab uaprs

rename uaprs  T14_i9 

*==============================================================================*


