*==============================================================================*
* TÍTULO DE LA SINTAXIS:													   *
* Datos de la vivienda y el hogar									           *
* OPERACIÓN ESTADÍSTICA:													   *
* Encuesta Nacional de Salud y Nutrición (ENSANUT - 2018)					   *										   
*==============================================================================*
* Fecha de elaboración:        20 de Diciembre del 2018						   *
* Fecha última modificación:   19 de Diciembre del 2019					   	   *
*==============================================================================*
* Elaborado por:                                                               *
* Instituto Nacional de Estadística y Censos (INEC)							   *
* Link:                                                                        *
* www.ecuadorencifras.gob.ec 												   *
*==============================================================================*

clear all
set more off
*En esta sección se copia la dirección en donde se encuentran las bases de datos
cd "C:\ENSANUT 2018\Bases de datos\Bases_trabajadas"

use 2_BDD_ENS2018_f1_hogar, clear

svyset upm [iw=fexp], strata(estrato) vce(linearized) singleunit(certainty) 

*------------------------------------------------------------------------------*
* T1_i1. Eliminación de Excretas
*------------------------------------------------------------------------------*

/* El Estado garantiza el derecho a un hábitat saludable y a vivir en un 
   ambiente sano. 
El indicador es una aproximación que mide el derecho a tener una vivienda con
condiciones mínimas de saneamiento que se correlaciona con un potencial 
ambiente saludable. Son hogares no privados aquellos que eliminan las excretas 
por alcantarillado y pozo séptico. 
La forma de eliminación de excretas a través de pozo séptico no garantiza un 
ambiente sano. */

*** Calculo

gen     T1_i1 = 0 if f1_s1_13!=. 
replace T1_i1 = 100 if ((area==1 & inrange(f1_s1_13,2,5)) | ///
			         (area==2 & inrange(f1_s1_13,3,5)))   
label var T1_i1 "Viviendas sin adecuado sistema de eliminación de excretas"
svy: mean T1_i1

*------------------------------------------------------------------------------*
* T1_i2. Hogares que utilizan suministros seguros de agua para beber (%)
*------------------------------------------------------------------------------*

	 /* Componentes del indicador:
		1) tipo de suministro
		2) calidad del agua
		3) cercannia del suministro
		4) suficiencia de agua para beber */

*** Cálculo

** 1. Tipo de suministro

recode f1_s1_21 (1/3   =1 "tuberia")(4/7   =2 "Otro"), gen(f1_s1_21r)

recode f1_s1_25 (1/3 7 9    = 1 "tipo A") ///
				(4 8 10 12  = 2 "tipo B") ///
				(11 13      = 3 "tipo C"), gen(agua_cp1) 
label var agua_cp1 "tipo de suministro"	
replace agua_cp1 = 1 if inlist(f1_s1_25,5,6) & f1_s1_21r==1
replace agua_cp1 = 2 if inlist(f1_s1_25,5,6) & f1_s1_21r==2

** 2. Calidad del agua -tratamiento-
	* 2.1.- Si la beben tal como llega al hogar, no tiene agua segura.
	* 2.2.- Si la hierven o tiene algún otro tratamiento, tiene calidad.
	* 2.3.- La respuesta "no sabe" no será tomada en cuenta 
	
gen     agua_cp2 =.
replace agua_cp2 =1 if inlist(f1_s1_30,2,3)
replace agua_cp2 =2 if 		  f1_s1_30==1 

label def agua_cp2 1 "Sí" 2 "No", replace
label val agua_cp2 agua_cp2
label var agua_cp2 "Calidad de agua"


** 3. Cercania del suministro
gen     agua_cp3 = 0 
replace agua_cp3 = 1 if inlist(f1_s1_26,1,2) 
replace agua_cp3 = 1 if inlist(f1_s1_25,5,6)
	* Nota.- el supuesto es que el agua embotellada este apta para el consumo
replace agua_cp3 = 2 if f1_s1_26==3 & f1_s1_27 <=30 & f1_s1_27!=.
replace agua_cp3 = 3 if f1_s1_26==3 & f1_s1_27 > 30 & f1_s1_27!=.  
	
replace agua_cp3 = . if f1_s1_27==888 & (f1_s1_26!=1 | f1_s1_26!=2) 
	* Se encuentra fuera de la vivienda, edifico/lote y no sabe a cuantos
	* minutos se encuentra de la fuente 

lab def agua_cp3 		   ///
1 "terreno/edificio" 	   ///
2 "menos o igual a 30 min" ///
3 "mas de 30 min", replace
label values agua_cp3 agua_cp3
label var agua_cp3 "cercania del suministro"

** 4. Suficiencia de agua para beber
gen     agua_cp4 = 0
replace agua_cp4 = 1 if f1_s1_28==1
replace agua_cp4 = 2 if f1_s1_28 >1 & f1_s1_28!=.
replace agua_cp4 = . if f1_s1_28==3
label def agua_cp4 1 "continuo" 2 "no continuo", replace
label val agua_cp4 agua_cp4
label var agua_cp4 "continuidad del suministro"

gen i_agua = 0 if !mi(agua_cp1) & !mi(agua_cp2) & !mi(agua_cp3) & !mi(agua_cp4) 

** Indicador de agua:
	* manejo seguro
replace i_agua = 1 if agua_cp1==1 & agua_cp2==1 & agua_cp3==1 & agua_cp4==1
	* Básico 1
replace i_agua = 2 if agua_cp1==1 & agua_cp2==1 & agua_cp3==1 & agua_cp4==2 /**/
replace i_agua = 2 if agua_cp1==1 & agua_cp2==1 & agua_cp3==2 /**/
	* Básico 2
replace i_agua = 3 if agua_cp1==1 & agua_cp2==2 & agua_cp3==1 /**/
replace i_agua = 3 if agua_cp1==1 & agua_cp2==2 & agua_cp3==2 /**/
	* limitado
replace i_agua = 4 if agua_cp1==1 				& agua_cp3==3 
	* no mejorado
replace i_agua = 5 if agua_cp1==2
	* superficial
replace i_agua = 6 if agua_cp1==3

label def i_agua ///
1 "Seguro" 		 ///
2 "Basico 1" 	 ///
3 "Basico 2" 	 ///
4 "limitado" 	 ///
5 "No mejorado"  ///
6 "Superficial", replace
label values i_agua i_agua
label var i_agua "Servicios de agua para beber manejado de forma segura"

	gen     T1_i2 = 0 if i_agua!=. 
	replace T1_i2 = 100 if i_agua==1  
	
*------------------------------------------------------------------------------*

