*==============================================================================*
* TÍTULO DE LA SINTAXIS:													   *
* Desarrollo infantil 	 					                        	   	   *
* OPERACIÓN ESTADÍSTICA:													   *
* Encuesta Nacional de Salud y Nutrición (ENSANUT - 2018)					   *
*==============================================================================*
* Fecha de elaboración:        28 de Octumbre del 2019						   *
* Fecha última modificación:   19 de Diciembre del 2019					   	   *
*==============================================================================*
* Elaborado por:                                                               *
* Instituto Nacional de Estadística y Censos (INEC)							   *
* Link:                                                                        *
* www.ecuadorencifras.gob.ec 												   *
*==============================================================================*

*------------------------------------------------------------------------------*
	* GRUPO ETARIO
*------------------------------------------------------------------------------*
recode edadmeses (0/6=1 "0-6") (7/11=2 "7-11") (12/18=3 "12-18") ///
(19/24=4 "19-24") (25/30=5 "25-30") (31/36=6 "31-36") (37/42=7 "37-42") ///
(43/48=8 "43-48") (49/54=9 "49-54") (55/59=10 "55-59")(mis=.), gen(eta1)
lab var eta1 "Grupo etario por semestres MacArthur"

*------------------------------------------------------------------------------*
	* T20_vi_1: Promedio de palabras que entienden los niños de 12 a 18  meses
*------------------------------------------------------------------------------*

***CÁLCULO
#delimit
global num "01 02 03 04 05 06 07 08 09 10 
11 12 13 14 15 16 17 18 19 20 
21 22 23 24 25 26 27 28 29 30 
31 32 33 34 35 36 37 38 39 40 
41 42 43 44 45 46 47 48 49 50" ;
#delimit cr

foreach n of global num {
gen entiende1_6`n' = . 
replace entiende1_6`n' = 1 if (f5_s6_6`n'==1 | f5_s6_6`n'==2) 
replace entiende1_6`n' = 0 if f5_s6_6`n'==3  
replace entiende1_6`n' = . if f5_s6_6`n'==4  
}
* Número de palabras que no responde el niño
egen missing_12_18_entiende=rowmiss(entiende1_6*) if f5_s6_600!=.
la var missing_12_18_entiende "Respuestas en missing para prueba McArthur 12-18 meses - entiende"
ta   missing_12_18_entiende 

egen num_entiende_1 = rowtotal(entiende1_6*), m 

cap drop T20_vi_1
cap label drop T20_vi_1
gen T20_vi_1=.
replace T20_vi_1=num_entiende_1 
replace T20_vi_1 =. if missing_12_18_entiende >=10 
label var T20_vi_1 "Promedio de palabras que entienden los niños de 12 a 18  meses"
mean T20_vi_1 if inrange(edadmeses,12,18)
svy: mean T20_vi_1 if inrange(edadmeses,12,18)

*------------------------------------------------------------------------------*
	* T20_vi_2: Promedio de palabras que dicen los niños de 12 a 18  meses
*------------------------------------------------------------------------------*

***CÁLCULO
#delimit
global num "01 02 03 04 05 06 07 08 09 10 
11 12 13 14 15 16 17 18 19 20 
21 22 23 24 25 26 27 28 29 30 
31 32 33 34 35 36 37 38 39 40 
41 42 43 44 45 46 47 48 49 50" ;
#delimit cr

foreach n of global num {
gen dice1_6`n' = . 
replace dice1_6`n' = 1 if f5_s6_6`n'==1 
replace dice1_6`n' = 0 if (f5_s6_6`n'==2 | f5_s6_6`n'==3)
replace dice1_6`n' = . if f5_s6_6`n'==4 
}
* Número de palabras que no responde el niño
egen missing_12_18=rowmiss(dice1_6*) if f5_s6_600!=.
la var missing_12_18 "Respuestas en missing para prueba McArthur 12-18 meses -dice"
ta   missing_12_18

egen num_dice_1 = rowtotal(dice1_6*),m 

cap drop T20_vi_2
cap label drop T20_vi_2
gen T20_vi_2=.
replace T20_vi_2=num_dice_1 
replace T20_vi_2 =. if missing_12_18 >=10 
label var T20_vi_2 "Promedio de palabras que dicen los niños de 12 a 18 meses"
mean T20_vi_2 if inrange(edadmeses,12,18)

*------------------------------------------------------------------------------*
	* T20_vii_1: Promedio de palabras que dicen los niños de 19 a 30 meses
*------------------------------------------------------------------------------*

***CÁLCULO
#delimit
global num "01 02 03 04 05 06 07 08 09 10 
11 12 13 14 15 16 17 18 19 20 
21 22 23 24 25 26 27 28 29 30 
31 32 33 34 35 36 37 38 39 40 
41 42 43 44 45 46 47 48 49 50" ;
#delimit cr

foreach n of global num {
gen dice2_7`n'=. 
replace dice2_7`n'=1 if f5_s7_7`n'==1 
replace dice2_7`n'=0 if f5_s7_7`n'==2 
}

* Número de palabras que no responde el niño
egen missing_19_30=rowmiss(dice2_7*) if f5_s7_700!=.
la var missing_19_30 "Respuestas en missing para prueba McArthur 19-30 meses"
ta   missing_19_30

egen num_dice_2 = rowtotal(dice2_7*),m 

cap drop T20_vii_1
cap label drop T20_vii_1
gen T20_vii_1=.
replace T20_vii_1=num_dice_2 
replace T20_vii_1 =. if missing_19_30 >=10 
label var T20_vii_1 "Promedio de palabras que dicen los niños de 19 a 30 meses"
mean T20_vii_1 if inrange(edadmeses,19,30)
mean T20_vii_1 if inrange(edadmeses,19,30), over(eta1)

*------------------------------------------------------------------------------*
	* T20_viii_1: Promedio de palabras que dicen los niños de 31 a 42 meses
*------------------------------------------------------------------------------*

***CÁLCULO. 
#delimit
global num "01 02 03 04 05 06 07 08 09 10 
11 12 13 14 15 16 17 18 19 20 
21 22 23 24 25 26 27 28 29 30 
31 32 33 34 35 36 37 38 39 40 
41 42 43 44 45 46 47 48 49 50" ;
#delimit cr

foreach n of global num {
gen dice3_8`n'=. 
replace dice3_8`n'=1 if f5_s8_8`n'==1 
replace dice3_8`n'=0 if f5_s8_8`n'==2 
}

* Número de palabras que no responde el niño
egen missing_31_42=rowmiss(dice3_8*) if f5_s8_800!=.
la var missing_31_42 "Respuestas en missing para prueba McArthur 19-30 meses"
ta   missing_31_42

egen num_dice_3 = rowtotal(dice3_8*), m 

cap drop T20_viii_1
cap label drop T20_viii_1
gen T20_viii_1=.
replace T20_viii_1=num_dice_3 
replace T20_viii_1 =. if missing_31_42 >=10 
label var T20_viii_1 "Promedio de palabras que dicen los niños de 31 a 42 meses"
mean T20_viii_1 if inrange(edadmeses,31,42)
mean T20_viii_1 if inrange(edadmeses,31,42), over(eta1)

