*==============================================================================*
* TÍTULO DE LA SINTAXIS:													   *
* Desarrollo infantil 	 					                        	   	   *
* OPERACIÓN ESTADÍSTICA:													   *
* Encuesta Nacional de Salud y Nutrición (ENSANUT - 2018)					   *
*==============================================================================*
* Fecha de elaboración:        28 de Octumbre del 2019						   *
* Fecha última modificación:   19 de Diciembre del 2019					   	   *
*==============================================================================*
* Elaborado por:                                                               *
* Instituto Nacional de Estadística y Censos (INEC)							   *
* Link:                                                                        *
* www.ecuadorencifras.gob.ec 												   *
*==============================================================================*

clear all
set more off
* En esta sección se copia la dirección en donde se encuentran las bases de datos
cd "C:\ENSANUT 2018\Bases de datos\Bases_trabajadas"
global general = "C:\ENSANUT 2018\Indicadores\sintaxis_publicación"

use 9_BDD_ENS2018_f5_des_inf, clear

svyset upm [iw=fexp], strata(estrato) vce(linearized) singleunit(certainty) 

* =================== *
* Sección i: Registro *
* =================== *

gen T20_i =  f1_s7_0_1
recode T20_i (1=100) (2=0) (3=.)
la var T20_i "Porcentaje de niños que cuentan con cédula de identidad o ciudadanía"


* ================================= *
* Sección ii: Cobertura de atención *
* ================================= *

	* ---------------------------------------------- *
	* 1. Asistencia a Programas de educación inicial *
	* ---------------------------------------------- *

	* CDI / actual 
gen     T20_ii_0=0   if f5_s2_200!=.  & f5_s1_100_6<4
replace T20_ii_0=100 if f5_s2_200==1  & f5_s1_100_6<4
label var T20_ii_0 "Porcentaje de niños que asisten menores de 4 años a un centro de cuidado infantil (público o privado)"

	* Tipo de centro para los que asisten actualmente 
gen T20_ii_3_1=f5_s2_203 if T20_ii_0==100
la val T20_ii_3_1 f5_s2_203
label var T20_ii_3_1 "Tipo de Centro de Desarrollo infantil CIBV/CDI, o guardería, al que asiste"	
	
	* CDI público/ privado actual
gen     T20_ii_3_2=0   if T20_ii_3_1!=.
replace T20_ii_3_2=100 if T20_ii_3_1==1 | T20_ii_3_1==2 | T20_ii_3_1==3   
la var T20_ii_3_2 "Porcentaje de ninos que asisten a programa de educación inicial publico"

recode T20_ii_3_2 (100=0) (0=100), gen(T20_ii_3_3)
la var T20_ii_3_3 "Porcentaje de ninos que asisten a programa de educación inicial privado"
	
	* 2. Asistencia a CNH
gen     T20_ii_6=0   if f5_s2_206!=. & f5_s1_100_6<3
replace T20_ii_6=100 if f5_s2_206==1 & f5_s1_100_6<3
label var T20_ii_6 "Porcentaje de niños menores de 3 años que reciben asistencia de Creciendo con Nuestros Hijos (CNH) en su hogar" 
	
* ================================= *	
* Sección iii: Calidad del ambiente *
* ================================= *
	* -------------------------------------- *
	* 1. Promoción de desarrollo en el hogar *
	* -------------------------------------- *
	
	* Variedad de actividades de juego 
	
foreach n in a b c d e f g {
gen act`n'= f5_s3_307`n'_1
recode act`n' (2=0)
}
*

egen T20_iii_7_1=rowtotal(acta actb actc actd acte actf actg),m
la var T20_iii_7_1 "# de acts. de estimulación tempr realizadas por niñas/os con miembros del hogar" 
drop act*		

gen     T20_iii_7_2=0   if T20_iii_7_1!=. 
replace T20_iii_7_2=100 if T20_iii_7_1>=4 & T20_iii_7_1!=.     
la var T20_iii_7_2 "Porcentaje de niños que realizan cuatro o más actividades de estimulación con cualquier cuidador en los últimos 3 días"	 

	* Variedad de actividades con la madre

foreach x  in a b c d e f g { 	
gen act_`x' = 0 if f5_s3_307`x'_1==2
replace act_`x'= 1 if f5_s3_307`x'_1==1 & f5_s3_307`x'_2_1==1 
}	

egen actividades_m = rowtotal(act_a-act_g), m
replace actividades_m =. if f1_s2_15 == 2

gen     T20_iii_7_4=0   if actividades_m != .   
replace T20_iii_7_4=100 if actividades_m >= 4 & actividades_m != .  
la var T20_iii_7_4 "Porcentaje de niños/as que han realizado 4 o más actividades con la madre para promover estim temprana"

drop act*

	* Variedad de actividades con el padre
foreach x  in a b c d e f g { 	
gen act_`x' = 0 if f5_s3_307`x'_1==2
replace act_`x'= 1 if f5_s3_307`x'_1==1 & f5_s3_307`x'_2_2==1 
}	

egen actividades_p = rowtotal(act_a-act_g), m
replace actividades_p =. if f1_s2_14 == 2

gen     T20_iii_7_5=0   if actividades_p != .
replace T20_iii_7_5=100 if actividades_p >= 4 & actividades_p != .    
la var T20_iii_7_5 "Porcentaje de niños/as que han realizado 4 o más actividades con el padre para promover estim temprana"

drop act*	

	* Libros infantiles (Promedio de libros infantiles para ninos en el hogar)
	
gen T20_ii_15_1 = f5_s2_215 
mvdecode T20_ii_15_1, mv(99) 
label var T20_ii_15_1 "Promedio de libros, cuentos, revistas o libros con dibujos para niños que tienen en el hogar"

	* Ninos con vs sin libros
gen     T20_ii_15_2=0   if T20_ii_15_1!=. 
replace T20_ii_15_2=100 if T20_ii_15_1>=1 & T20_ii_15_1!=.     
la var T20_ii_15_2 "Porcentaje de ninos que tienen al menos un libro, cuento o revista infantil"	
	
	* Ninos con por lo menos tres libros infantiles 
gen     T20_ii_15_3=0   if T20_ii_15_1!=.
replace T20_ii_15_3=100 if T20_ii_15_1>=3 & T20_ii_15_1!=. 	
la var T20_ii_15_3 "Porcentaje de ninos que tienen por lo menos tres libros infantiles"	

	* ---------------------------------- *
	* 2. Actividades promotoras de juego *
    * ---------------------------------- *

foreach x in d e f g {
gen     juego_`x'=0   if f5_s3_301`x'!=. 
replace juego_`x'=100 if f5_s3_301`x' == 1  
}
		
egen tipo_juguete = rowtotal(juego_* T20_ii_15_2),m 
gen     T20_iii_1_2=0   if tipo_juguete!=.
replace T20_iii_1_2=100 if tipo_juguete>=300 & tipo_juguete!=.     
label var T20_iii_1_2 "Porcentaje de niños/as que juegan con tres o más tipos de juguetes"   

drop juego_* 
	
	* -------------------------- *
	* 3. Prácticas de disciplina * 
	* -------------------------- *

	* Porcentaje de niños entre 1 a menores de 5 años que recibieron maltrato físico en el último mes             

gen     T20_iv_0_1=0   if (f5_s4a_400c!=. | f5_s4a_400f!=. | f5_s4a_400g!=. | f5_s4a_400i!=. | f5_s4a_400j!=. | f5_s4a_400k!=. | f5_s4a_400m!=.)
replace T20_iv_0_1=100 if (f5_s4a_400c==1 | f5_s4a_400f==1 | f5_s4a_400g==1 | f5_s4a_400i==1 | f5_s4a_400j==1 | f5_s4a_400k==1 | f5_s4a_400m==1)
label var T20_iv_0_1 "Porcentaje de niños >1 & <5 años que recibieron maltrato físico en el último mes" 

	* Porcentaje de niños entre 1 a menores de 5 años que recibieron maltrato psicológico en el último mes              

gen T20_iv_0_3=.
replace T20_iv_0_3=0   if (f5_s4a_400d!=. | f5_s4a_400h!=.)
replace T20_iv_0_3=100 if (f5_s4a_400d==1 | f5_s4a_400h==1)
label var T20_iv_0_3 "Porcentaje de niños >1 & <5 años que recibieron maltrato psicológico en el último mes" 

	* Porcentaje de niños menores de 1 año que recibieron maltrato físico en el último mes               

gen T20_iv_1_1=.
replace T20_iv_1_1=0   if (f5_s4b_401f!=. | f5_s4b_401h!=.)
replace T20_iv_1_1=100 if (f5_s4b_401f==1 | f5_s4b_401h==1)
label var T20_iv_1_1 "Porcentaje de niños <1 año que recibieron maltrato físico en el último mes" 

	* Porcentaje de niños menores de 1 año que recibieron maltrato psicológico en el último mes                 

gen T20_iv_1_3=.
replace T20_iv_1_3=0   if (f5_s4b_401b!=. | f5_s4b_401d!=. | f5_s4b_401i!=.) 
replace T20_iv_1_3=100 if (f5_s4b_401b==1 | f5_s4b_401d==1 | f5_s4b_401i==1)
label var T20_iv_1_3 "Porcentaje de niños menores de 1 año que recibieron maltrato psicológico en el último mes"

	* -------------- *
	* 4. Negligencia *
	* -------------- *
	
	* Ninos que quedaron al cuidado de un menor de 10 años por más de una hora en los últimos 7 días  

gen T20_iii_5=.
replace T20_iii_5=f5_s3_305 if f5_s3_305 <= 7
label var T20_iii_5 "Días en que quedó al cuidado de un menor de 10 años por +1 hora en los últimos 7 días"

gen     T20_iii_5_1=0   if T20_iii_5!=. 
replace T20_iii_5_1=100 if T20_iii_5>=1 & T20_iii_5!=.  
la var T20_iii_5_1 "Porcentaje de ninos dejados al cuidado de un menor de 10 años más de una hora en los últimos 7 días"

	* Porcentaje de niños menores de 5 años que en los últimos 7 días no se quedaron solos por más de una hora 

gen     T20_iii_6=0   if f5_s3_306!=. 
replace T20_iii_6=100 if f5_s3_306>=1 & f5_s3_306!=.   
la var  T20_iii_6 "Porcentaje de niños que se quedaron solos al menos una hora en la última semana" 
	
* =============================== *	
* Sección iv: Desarrollo Infantil 	
* =============================== *
	
	* ---------------------------------------------------------- *
	* 1. Porcentaje de niños en desarrollo adecuado para la edad *
	* ---------------------------------------------------------- *
	
/* 
Encoding: UTF-8.
 * Responses to questions EC6-EC15 are used to determine whether children are developmentally on track in four domains: 
   Literacy-numeracy: Developmentally on track if at least two of the following are true: 
  EC6=1 (Can identify/name at least ten letters of the alphabet), 
  EC7=1 (Can read at least four simple, popular words), 
  EC8=1 (Knows the name and recognizes the symbol of all numbers from 1 to 10).
 * Physical: Developmentally on track if one or both of the following is true: 
  EC9=1 (Can pick up a small object with two fingers, like a stick or a rock from the ground), 
  EC10=2 (Is not sometimes too sick to play).
 * Social-emotional: Developmentally on track if at least two of the following are true: 
  EC13=1 (Gets along well with other children), 
  EC14=2 (Does not kick, bite, or hit other children), 
  EC15=2 (Does not get distracted easily).
 * Learning: Developmentally on track if one or both of the following is true: 
  EC11=1 (Follows simple directions on how to do something correctly), 
 EC12=1 (When given something to do, is able to do it independently).

 * MICS indicator TC.53 is calculated as the percentage of children who are developmentally on track in at least three of the four component domains (literacy-numeracy, physical, social-emotional, and learning).
*/

cap drop abc palabras numeros sum_alfa_num alfa_num 
gen abc=0 if f5_s5_501!=. 
replace abc=1 if f5_s5_501==1 
gen palabras=0 if f5_s5_502!=. 
replace palabras=1 if f5_s5_502==1 
gen numeros=0 if f5_s5_503!=.
replace numeros=1 if f5_s5_503==1 
egen sum_alfa_num = rsum(abc palabras numeros),m 
gen alfa_num=0 if sum_alfa_num!=. 
replace alfa_num=1 if sum_alfa_num>=2 & sum_alfa_num!=. 

cap drop recoger cansado fisica 
gen recoger=0 if f5_s5_504!=. 
replace recoger=1 if f5_s5_504==1 
gen cansado=0 if f5_s5_505!=.
replace cansado=1 if f5_s5_505==2 
gen fisica=0 if recoger!=. | cansado!=.
replace fisica=1 if recoger==1 | cansado==1 

cap drop relacion golpea distrae sum_socio_emo socio_emo
gen relacion=0 if f5_s5_508!=. 
replace relacion=1 if f5_s5_508==1 
gen golpea=0 if f5_s5_509!=. 
replace golpea=1 if f5_s5_509==2 
gen distrae=0 if f5_s5_510!=.
replace distrae=1 if f5_s5_510==2 
egen sum_socio_emo = rsum(relacion golpea distrae), m 
gen socio_emo=0 if sum_socio_emo!=.
replace socio_emo=1 if sum_socio_emo>=2 & sum_socio_emo!=. 

cap drop instrucciones solo aprendizaje
gen instrucciones=0 if f5_s5_506!=. 
replace instrucciones=1 if f5_s5_506==1 
gen solo=0 if f5_s5_507!=. 
replace solo=1 if f5_s5_507==1 
gen aprendizaje=0 if instrucciones!=. | solo!=. 
replace aprendizaje=1 if instrucciones==1 | solo==1 

cap drop sum_desarrollo T20_v_0
egen sum_desarrollo = rsum(alfa_num fisica socio_emo aprendizaje), m 
gen     T20_v_0=0   if sum_desarrollo!=. 
replace T20_v_0=100 if sum_desarrollo>=3 & sum_desarrollo!=.
label var T20_v_0 "Porcentaje de ninos 36-59 meses que se están desarrollando acorde con su edad"  

	* -------------------- *
	* 3. Motricidad gruesa *
	* -------------------- *
	
	* Último hito *

forval x=1/6 {
gen hito_`x' = `x' if f5_s12_`x'_1==1
}	
	
egen hitos=rownonmiss(hito_1-hito_6)	
egen max_hito=rowmax(hito_1 hito_2 hito_3 hito_4 hito_5 hito_6)
	
gen ult_hito=0 if f5_s12_1_1 == 2 & f5_s12_2_1 == 2 & f5_s12_3_1 == 2 & f5_s12_4_1 == 2 & f5_s12_5_1 == 2 & f5_s12_6_1 == 2 

forval x=1/6 {
replace ult = `x' if f5_s12_`x'_1==1 & f5_s12_`x'_3==1
} 

gen sin_ult=1 if ult_hito==. & edadmeses<24 
replace ult_hito=max_hito if ult_hito==. & edadmeses<24

label def ult 0"Ninguno" 1"Sentarse solo" 2"Gatear" 3"Pararse con ayuda" 4"Caminar con ayuda" 5"Pararse Solo" 6"Caminar solo"
label val ult ult

	* Edad último hito
gen edad_ult_hito=. 
forval x=1/6 {
replace edad_ult_hito = f5_s12_`x'_4 if ult_hito==`x'
}

gen falta_edad_ult_hito=1 if edadmeses<24 & edad_ult_hito==. & ult_hito!=0 

	* Puntaje continuo hitos // supuesto: si ya cumplió un hito y no los anteriores, se asigna este valor como número de hitos 

replace hitos=2 if ult_hito==2 & hitos==1	
replace hitos=3 if ult_hito==3 & hitos<2
replace hitos=4 if ult_hito==4 & hitos<4
replace hitos=5 if ult_hito==5 & hitos<5
replace hitos=6 if ult_hito==6 & hitos!=6	

rename hitos T20_xii_7
replace T20_xii_7=. if edadmeses>18
la var T20_xii_7 "Número de hitos" 
	
	* 4. Lenguaje 
cap drop eta*	
do "$general/T20_2.do"	

*==============================================================================*

rename 	T20_i      	T20_i1
rename 	T20_ii_0	T20_i2
rename 	T20_ii_6	T20_i3
rename 	T20_ii_15_2	T20_i4
rename 	T20_ii_15_3	T20_i5
rename 	T20_iii_1_2 T20_i6
rename 	T20_iii_7_2	T20_i7
rename  T20_iii_7_4 T20_i8
rename  T20_iii_7_5	T20_i9
rename 	T20_iv_0_1	T20_i10
rename 	T20_iv_0_3	T20_i11
rename 	T20_iv_1_1	T20_i12
rename 	T20_iv_1_3	T20_i13
rename 	T20_iii_5_1	T20_i14
rename 	T20_iii_6	T20_i15
rename 	T20_v_0 	T20_i16
rename 	T20_xii_7	T20_i17
rename 	T20_vi_1	T20_i18
rename 	T20_vi_2	T20_i19
rename 	T20_vii_1	T20_i20
rename 	T20_viii_1	T20_i21

*==============================================================================*

