*============================================================================*
* TÍTULO DE LA SINTAXIS:													   *
* Características ocupacionales  	 					                  	   *
* OPERACIÓN ESTADÍSTICA:													   *
* Encuesta Nacional de Salud y Nutrición (ENSANUT - 2018)					   *
*==============================================================================*
* Fecha de elaboración:        3  de Enero del 2018						       *
* Fecha última modificación:  19 de Diciembre del 2019				   	   	   *
*==============================================================================*
* Elaborado por:                                                               *
* Instituto Nacional de Estadística y Censos (INEC)							   *
* Link:                                                                        *
* www.ecuadorencifras.gob.ec 												   *
*==============================================================================*

clear all
set more off

cd "C:\ENSANUT 2018\Bases de datos\Bases_trabajadas"

use 1_BDD_ENS2018_f1_personas, clear 

merge m:1 id_hogar using 2_BDD_ENS2018_f1_hogar, force
keep if _merge==3
drop _merge

svyset upm [iw=fexp], strata(estrato) vce(linearized) singleunit(certainty) 

*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*
*****************INDICADOR DE POBREZA Y POBREZA EXTREMA POR NBI*****************
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*

*El método abarca cinco dimensiones y dentro de cada dimensión existe 
*indicadores que miden privaciones

*------------------------------------------------------------------------------*
*1.-CAPACIDAD ECONÓMICA 
*------------------------------------------------------------------------------*

*El hogar se considera privado de está dimensión si: 
*i) Los años de escolarida del jefe(a) del hogar es menor o igual a 2 años y; 
*ii) Existen más de tres personas por cada persona ocupada del hogar 

***Escolaridad del jefe de hogar 

gen     escol=.
replace escol=0         if f1_s2_19_1==1 & f1_s2_7==1 
replace escol=2 * f1_s2_19_2   if f1_s2_19_1==2 & inrange(f1_s2_19_2,0,3) & f1_s2_7==1
replace escol=3 + f1_s2_19_2   if f1_s2_19_1==2 & inrange(f1_s2_19_2,4,10) & f1_s2_7==1
replace escol=1         if f1_s2_19_1==3 & f1_s2_7==1
replace escol=1  + f1_s2_19_2 if f1_s2_19_1==4 & f1_s2_7==1
replace escol=     f1_s2_19_2 if f1_s2_19_1==5 & f1_s2_7==1
replace escol=7  + f1_s2_19_2 if f1_s2_19_1==6 & f1_s2_7==1
replace escol=10 + f1_s2_19_2 if f1_s2_19_1==7 & f1_s2_7==1
replace escol=13 + f1_s2_19_2 if f1_s2_19_1==8 & f1_s2_7==1
replace escol=13 + f1_s2_19_2 if f1_s2_19_1==9 & f1_s2_7==1
replace escol=18 + f1_s2_19_2 if f1_s2_19_1==10 & f1_s2_7==1
gen escjefe_=1 if escol<3 & f1_s2_7==1
replace escjefe_=0 if escol>=3 & f1_s2_7==1
egen escjefe= max(escjefe_), by(id_hogar)

***Ocupación 
gen ocup=1 if f1_s2_3_1>=15 & f1_s3_1==1
replace ocup=1 if f1_s2_3_1>=15 & (f1_s3_1==2 & f1_s3_2<=11)
replace ocup=1 if f1_s2_3_1>=15 & (f1_s3_1==2 & f1_s3_2==12 & f1_s3_3==1)
replace ocup=0 if ocup!=1

***Número de ocupados y personas del hogar 
bys id_hogar: egen numper_ocu_= sum(ocup)
bys id_hogar: egen numpers= count(id_per)  

***Dependencia económica 
gen depec=1 if ((numpers/numper_ocu_)>3 & numper_ocu_>0 & escjefe==1)
replace depec=1 if (numper_ocu_==0 & escjefe==1) 
replace depec=0 if depec !=1

*------------------------------------------------------------------------------*
*2.-ACCESO A EDUCACIÓN BÁSICA 
*------------------------------------------------------------------------------*

*El hogar se considera privado en esta dimensión si: existe en el hogar niños 
*de 6 a 12 años de edad que no asisten a clases

gen ninastesc_=1 if (f1_s2_3_1>5 & f1_s2_3_1<13) & f1_s2_17==2
replace ninastesc_=0 if ninastesc_!=1 & (f1_s2_3_1>5 & f1_s2_3_1<13)
egen ninastesc= max(ninastesc_), by(id_hogar)
recode ninastesc (.=0)

*------------------------------------------------------------------------------*
*3.-ACCESO A VIVIENDA
*------------------------------------------------------------------------------*

*El hogar está privado si:
*i) El material del piso es de tierra u de otros materiales
*ii) El material de las paredes son de caña, estera u otros 

gen matviv_def=1 if  ((f1_s1_4==7 | f1_s1_4==8) | (f1_s1_5==6 | f1_s1_5==7))
replace matviv_def=0 if matviv_def!=1

*------------------------------------------------------------------------------*
*4.-ACCESO A SERVICIOS BÁSICOS 
*------------------------------------------------------------------------------*

*La dimensión considera las condiciones sanitarias de la vivienda.
*El hogar es pobre si:
*i) La vivienda no tiene servicio higiénico o si lo tiene es por pozo ciego o letrina 
*ii) Si el agua que obtiene la vivienda no es por red pública o por otra fuente de tubería 

gen ser_viv=1 if (f1_s1_13==3 | f1_s1_13==4 | f1_s1_13==5)
replace ser_viv=0 if ser_viv!=1

*------------------------------------------------------------------------------*
*5.-HACINAMIENTO  
*------------------------------------------------------------------------------*

*El hogar se considera pobre si la relación de personas por dormitorio es mayor a tres
   
gen f1_s1_8_dor=f1_s1_8
recode f1_s1_8_dor(0=1)
gen percuart=(numpers/f1_s1_8_dor)
gen hacm=1 if percuart>3 
replace hacm=0 if percuart<=3


*--------------------------------------------------------------------------------*
***CÁLCULO DEL INDICADOR DE NBI
*--------------------------------------------------------------------------------*

egen nbi =rsum(depec ninastesc matviv_def ser_viv hacm)

***Pobreza por NBI
cap drop T4_i1 
cap label drop T4_i1
gen T4_i1 = 100 if nbi >= 1
replace T4_i1 = 0 if T4_i1 != 100
label var T4_i1 "Pobreza por NBI" 
label def T4_i1 0 "No Pobre" 100 "Pobre" 
label val T4_i1 T4_i1

***Pobreza extrema por NBI
cap drop T4_i2 
cap label drop T4_i2
gen T4_i2 = 100 if nbi >= 2
replace T4_i2 = 0 if T4_i2 != 100
label var T4_i2 "Pobreza extrema por NBI" 
label def T4_i2 0 "No Pobre" 100 "Pobre" 
label val T4_i2 T4_i2

*--------------------------------------------------------------------------------*

