*==============================================================================*
* TÍTULO DE LA SINTAXIS:													   *
* Estado nutricional a partir de indicadores antropométricos				   *
* OPERACIÓN ESTADÍSTICA:													   *
* Encuesta Nacional de Salud y Nutrición (ENSANUT - 2018)					   *
*==============================================================================*
* Fecha de elaboración:       10 de Diciembre del 2018					       *
* Fecha última modificación:  19 de Diciembre del 2019				   	   	   *
*==============================================================================*
* Elaborado por:                                                               *
* Instituto Nacional de Estadística y Censos (INEC)							   *
* Link:                                                                        *
* www.ecuadorencifras.gob.ec 												   *
*==============================================================================*

*==============================================================================*
* Instrucciones:
* 1. Descargar las bases que tengan las variables antropometricas en formato .dta
* 2. Guardar en un directorio y copiar ese directorio en "cd"
* 3. Correr la programación en stata
* 4. Es necesario que exista conexión a internet para descargar el paquete 
*	 Child growth standards "igrowup_stata". 
*==============================================================================*
clear all
set more off
* En esta sección se copia la dirección en donde se encuentran las bases de datos
* que contienen las variables de antropometría (Ej: cd "C:\...")
cd "C:\ENSANUT 2018\Bases de datos\Bases_trabajadas"
global dir2 = "C:\Desnutricion\igrowup"
global dir3 = "C:\sobrepeso\Who2007"
global dirr = "C:\ENSANUT 2018\Resultados"

use 1_BDD_ENS2018_f1_personas, clear 

merge m:1 id_hogar using 2_BDD_ENS2018_f1_hogar
keep if _merge==3
drop _merge

svyset upm [iw=fexp], strata(estrato) vce(linearized) singleunit(certainty) 

*==============================================================================*
* Cálculo de variables antropométricas necesarias para el indicador
*==============================================================================*
*** 1.- Estimación de la edad (días)
cap drop edaddias 
** Fecha de nacimiento
gen dob=mdy(f1_s7_2_2,f1_s7_2_1,f1_s7_2_3)
** Fecha de medición 
gen dov=mdy(f1_s7_3_2,f1_s7_3_1,f1_s7_3_3)
** Edad en días
gen edaddias= dov-dob

*** 2.- Estimación del peso (kg)
* Validación de las 3 medidas del peso
gen aux = f1_s7_4_1 - f1_s7_4_2
replace aux = aux*-1 if aux<0
replace f1_s7_4_3=. if aux<=0.5 & f1_s7_4_3!=.
drop aux

* Se calcula el peso en kg.
gen peso=.
* Distancia entre las tres medidas
gen d1 = abs(f1_s7_4_1 - f1_s7_4_2) 
gen d2 = abs(f1_s7_4_1 - f1_s7_4_3) 
gen d3 = abs(f1_s7_4_2 - f1_s7_4_3) 
* Variable identificador si distancia entre toma 1 y toma 2 menor o igual a 0.5
gen s = 0 if f1_s7_4_1!=.
replace s = 1 if d1  <= 0.5
* Promedio simple entre toma 1 y toma 2
replace peso =(f1_s7_4_1+f1_s7_4_2)/2 if s==1
* Caso contrario, promedio de la menor distancia entre las 3 mediciones
* distancia mínima
gen dmin= min(d1,d2,d3)
replace peso = (f1_s7_4_1 + f1_s7_4_2)/2 if d1==dmin
replace peso = (f1_s7_4_1 + f1_s7_4_3)/2 if d2==dmin
replace peso = (f1_s7_4_2 + f1_s7_4_3)/2 if d3==dmin
drop d1 d2 d3 s dmin

*** 3.- Estimación de la talla (cm)
* Validación de las 3 medidas de la longitud
gen aux = f1_s7_5_1 - f1_s7_5_2
replace aux = aux*-1 if aux<0
replace f1_s7_5_3=. if aux<=0.5 & f1_s7_5_3!=.
drop aux
* Validación de las 3 medidas de la talla
gen aux = f1_s7_6_1 - f1_s7_6_2
replace aux = aux*-1 if aux<0
replace f1_s7_6_3=. if aux<=0.5 & f1_s7_6_3!=.
drop aux

* Se calcula la talla en cm.
gen talla =.
* Consolido las tomas para longitug y talla
egen talla1 = rowtotal(f1_s7_5_1 f1_s7_6_1), missing
egen talla2 = rowtotal(f1_s7_5_2 f1_s7_6_2), missing
egen talla3 = rowtotal(f1_s7_5_3 f1_s7_6_3), missing
* Distancia entre las tres medidas
gen d1 = abs(talla1- talla2)
gen d2 = abs(talla1- talla3)
gen d3 = abs(talla2- talla3)
* Variable identificador si distancia entre toma 1 y toma 2 menor o igual a 0.5
gen s = 0 if talla1 !=.
replace s = 1 if d1  <= 0.5
* Promedio simple entre toma 1 y toma 2
replace talla =(talla1+talla2)/2 if s==1
* Caso contrario, promedio de la menor distancia entre las 3 mediciones
* distancia mínima
gen dmin= min(d1,d2,d3)
replace talla = (talla1+talla2)/2 if d1==dmin
replace talla = (talla1+talla3)/2 if d2==dmin
replace talla = (talla2+talla3)/2 if d3==dmin
drop d1 d2 d3 s dmin

*** 4. Medida de talla o longitud
* H: Talla - L: Longitud 
gen medida="H" if f1_s7_6_1!=.
replace medida="L" if f1_s7_5_1!=.

*==============================================================================*
* Utilización del código de desnutrición de ANTHRO - OMS (igrowup)
*==============================================================================*
*Crear un nuevo directorio "igrowup":
local y ="$dir2"
cap mkdir "`y'"
cd "`y'"
adopath + "`y'"
*==============================================================================*
* Nota: En caso de no contar con el paquete, a continuación se encuestran los códigos
* de descarga:
*Descarga y extracción del paquete de Child growth standards "igrowup_stata":
*cap copy http://www.who.int/childgrowth/software/igrowup_stata.zip ///
*  igrowup_stata.zip
*cap unzipfile igrowup_stata.zip
*cd "`dir'"
*==============================================================================*
*Generar los tres primeros parámetros: reflib, datalib y datalab.
gen str200 reflib="`y'"
lab var reflib "Directory of reference tables"
gen str200 datalib="`y'"
lab var datalib "Directory for datafiles"
gen str30 datalab="f1_sn"
lab var datalab "Working file"

* Se generan las variables para la macro "igrowup".
gen sex=sexo
gen agemons=edaddias
gen str6 ageunit="days"
lab var ageunit "days"
gen weight=peso
gen height=talla
gen str1 measure=" "
gen headc=.
gen muac=.
gen triskin=.
gen subskin=.
gen sub=.
gen str1 oedema="n"
gen sw=-1

* Completar en la macro los parámetros para que corra el comando
igrowup_standard reflib datalib datalab sex agemons ///
ageunit weight height measure head muac tri sub oedema sw
drop reflib datalib datalab
*==============================================================================*
* Construcción de las variables de desnutrición con los zscore
** Definición de la edad en días de la población menor a 5 años:
** Dias= 365.25 * 5 = 1826.25 ----> 1826 (valor aproximado) (Manual Anthro OMS)
*==============================================================================*
* Cálculo para la población menor a 59 meses. 
*==============================================================================*
* T7_i1. Desnutrición crónica para menores de 5 años de edad
*==============================================================================*
cap drop dcronica 
gen 	dcronica=0 if _zlen>=-6 & _zlen<=6 // no se consideran outliers.
replace dcronica=100 if (_zlen!=. & agemons<1826 & _zlen< -2) & _zlen>=-6 & _zlen<=6
replace dcronica=. if (agemons>=1826)
replace dcronica=. if _zlen==.
rename dcronica T7_i1

*==============================================================================*
* T7_i2. Desnutrición global para menores de 5 años de edad
*==============================================================================*
cap drop dglobal 
gen 	dglobal=0 if _zwei>=-6 & _zwei<=5 // no se consideran outliers.
replace dglobal=100 if (_zwei!=. & agemons<1826 & _zwei<-2) & _zwei>=-6 & _zwei<=5
replace dglobal=. if (agemons>=1826)
replace dglobal=. if _zwei==.
rename dglobal T7_i2

*==============================================================================*
* T7_i3. Desnutrición aguda para menores de 5 años de edad
*==============================================================================*
cap drop daguda 
gen 	daguda=0 if _zwfl>=-5 & _zwfl<=5 // no se consideran outliers.
replace daguda=100 if (_zwfl!=. & agemons<1826 & _zwfl<-2) & _zwfl>=-5 & _zwfl<=5
replace daguda=. if (agemons>=1826)
replace daguda=. if _zwfl==.
rename daguda T7_i3
*==============================================================================*
* T7_i1_2. Desnutrición crónica para menores de 2 años de edad
*==============================================================================*
cap drop dcronica_2 
gen 	dcronica_2=0 if _zlen>=-6 & _zlen<=6 // no se consideran outliers.
replace dcronica_2=100 if (_zlen!=. & agemons<731 & _zlen< -2) & _zlen>=-6 & _zlen<=6
replace dcronica_2=. if (agemons>=731)
replace dcronica_2=. if _zlen==.
rename dcronica_2 T7_i1_2
*==============================================================================*
* T7_i2_2. Desnutrición global para menores de 2 años de edad
*==============================================================================*
cap drop dglobal_2 
gen 	dglobal_2=0 if _zwei>=-6 & _zwei<=5 // no se consideran outliers.
replace dglobal_2=100 if (_zwei!=. & agemons<731 & _zwei<-2) & _zwei>=-6 & _zwei<=5
replace dglobal_2=. if (agemons>=731)
replace dglobal_2=. if _zwei==.
rename dglobal_2 T7_i2_2
*==============================================================================*
* T7_i3_2. Desnutrición aguda para menores de 2 años de edad
*==============================================================================*
cap drop daguda_2 
gen 	daguda_2=0 if _zwfl>=-5 & _zwfl<=5 // no se consideran outliers.
replace daguda_2=100 if (_zwfl!=. & agemons<731 & _zwfl<-2) & _zwfl>=-5 & _zwfl<=5
replace daguda_2=. if (agemons>=731)
replace daguda_2=. if _zwfl==.
rename daguda_2 T7_i3_2
*==============================================================================*
* Utilización del codigo de sobrepeso y obesidad de ANTHRO - OMS (who2007)
*==============================================================================*
local y ="$dir3"
cap mkdir "`y'"
cd "`y'"
adopath + "`y'"

* Generar los tres primeros parámetros reflib, datalib & datalab
gen str60 reflib="`y'"
lab var reflib "Directory of reference tables"
gen str60 datalib="`y'"
lab var datalib "Directory for datafiles"
gen str30 datalab="survey_2007"
lab var datalab "Working file"

* Completar en la macro los parámetros para que corra el comando
who2007 reflib datalib datalab sex agemons ageunit weight height oedema sw 

*==============================================================================*
* T7_i4. Sobrepeso para niños de 5 a 11 años de edad (>=5 & <12)
*==============================================================================*
cap drop dsp5_11 
gen dsp5_11=0 if (_zbfa>=-5 & _zbfa<=5)
replace dsp5_11=100 if (_zbfa!=. & agemons>=1826 & agemons<=4382 & _zbfa>1 & _zbfa<=2 ) & (_zbfa>=-5 & _zbfa<=5)
replace dsp5_11=. if (agemons>4382) 
replace dsp5_11=. if (agemons<1826)
replace dsp5_11=. if _zbfa==.
rename dsp5_11 T7_i4
*==============================================================================*
* T7_i5. Obesidad para niños de 5 a 11 años de edad (>=5 & <12)
*==============================================================================*
cap drop dobes5_11 
gen dobes5_11=0 if (_zbfa>=-5 & _zbfa<=5)
replace dobes5_11=100 if (_zbfa!=. & agemons>=1826 & agemons<=4382 & _zbfa>2) & (_zbfa>=-5 & _zbfa<=5)
replace dobes5_11=. if (agemons>4382)
replace dobes5_11=. if (agemons<1826)
replace dobes5_11=. if _zbfa==.
rename dobes5_11 T7_i5
*==============================================================================*
* T7_i6. Sobrepeso y obesidad para niños de 5 a 11 años de edad (>=5 & <12)
*==============================================================================*
cap drop dspob5_11 
gen dspob5_11=0 if (_zbfa>=-5 & _zbfa<=5)
replace dspob5_11=100 if (_zbfa!=. & agemons>=1826 & agemons<=4382 & _zbfa>1 ) & (_zbfa>=-5 & _zbfa<=5)
replace dspob5_11=. if (agemons>4382)
replace dspob5_11=. if (agemons<1826)
replace dspob5_11=. if _zbfa==.
rename dspob5_11 T7_i6
*==============================================================================*
* T7_i7. Delgadez para niños de 5 a 11 años de edad (>=5 & <12)
*==============================================================================*
cap drop ddelg5_11 
gen ddelg5_11=0 if (_zbfa>=-5 & _zbfa<=5)
replace ddelg5_11=100 if (_zbfa!=. & agemons>=1826 & agemons<=4382 & _zbfa<-2) & (_zbfa>=-5 & _zbfa<=5)
replace ddelg5_11=. if (agemons>4382)
replace ddelg5_11=. if (agemons<1826)
replace ddelg5_11=. if _zbfa==.
rename ddelg5_11 T7_i7
*==============================================================================*
* T7_i8. Sobrepeso en adolescentes de 12 a 19 años y 1 mes de edad (228 meses)
*==============================================================================*
cap drop dsp12_19 
gen dsp12_19=0 if (_zbfa>=-5 & _zbfa<=5)
replace dsp12_19=100 if (_zbfa!=. & agemons>=4383 & agemons<=6970 & _zbfa>1 & _zbfa<=2) & (_zbfa>=-5 & _zbfa<=5)
replace dsp12_19=. if agemons<4383
replace dsp12_19=. if agemons>6970
replace dsp12_19=. if _zbfa==.
rename dsp12_19 T7_i8
*==============================================================================*
* T7_i9. Obesidad en adolescentes de 12 a 19 años y 1 mes de edad (228 meses)
*==============================================================================*
cap drop dobes12_19 
gen dobes12_19=0 if (_zbfa>=-5 & _zbfa<=5)
replace dobes12_19=100 if (_zbfa!=. & agemons>=4383 & agemons<=6970 & _zbfa>2) & (_zbfa>=-5 & _zbfa<=5)
replace dobes12_19=. if agemons<4383
replace dobes12_19=. if agemons>6970
replace dobes12_19=. if _zbfa==.
rename dobes12_19 T7_i9
*==============================================================================*
* T7_i10. Sobrepeso y obesidad en adolescentes de 12 a 19 años y 1 mes de edad (228 meses)
*==============================================================================*
cap drop dspob12_19 
gen dspob12_19=0 if (_zbfa>=-5 & _zbfa<=5)
replace dspob12_19=100 if (_zbfa!=. & agemons>=4383 & agemons<=6970 & _zbfa>1) & (_zbfa>=-5 & _zbfa<=5)
replace dspob12_19=. if agemons<4383
replace dspob12_19=. if agemons>6970
replace dspob12_19=. if _zbfa==.
rename dspob12_19 T7_i10
*==============================================================================*
* T7_i11. Delgadez en adolescentes de 12 a 19 años y 1 mes de edad (228 meses)
*==============================================================================*
cap drop ddelg12_19 
gen ddelg12_19=0 if  (_zbfa>=-5 & _zbfa<=5)
replace ddelg12_19=100 if (_zbfa!=. & agemons>=4383 & agemons<=6970 & _zbfa<-2) & (_zbfa>=-5 & _zbfa<=5)
replace ddelg12_19=. if agemons<4383
replace ddelg12_19=. if agemons>6970
replace ddelg12_19=. if _zbfa==.
rename ddelg12_19 T7_i11
*==============================================================================*
* Medidas antropometricas para adultos (no se usan tablas de crecimiento) 
*==============================================================================*
* Correccion para valores outlier de IMC (>5std &  <-5 std)
* Z cbmi:(x-µ)/std
sum _cbmi if (agemons>=6971 & agemons<=21899)
gen _zcbmi=(_cbmi-  r(mean))/ r(sd) if (agemons>=6971 & agemons<=21899)
replace _cbmi=. if (_zcbmi<-5 | _zcbmi>5)

*==============================================================================*
* T7_i12. Bajo peso en adultos de 19 a 59 años de edad
*==============================================================================*
cap drop dbpeso19_59 
gen dbpeso19_59=0
replace dbpeso19_59=100 if (_cbmi!=. & agemons>=6971 & agemons<=21899 & _cbmi <18.5)
replace dbpeso19_59=. if agemons<6971
replace dbpeso19_59=. if agemons>21899
replace dbpeso19_59=. if _cbmi==.
rename dbpeso19_59 T7_i12
*==============================================================================*
* T7_i13. Peso Normal en adultos de 19 a 59 años de edad
*==============================================================================*
cap drop dnorm19_59 
gen dnorm19_59=0
replace dnorm19_59=100 if (_cbmi!=. & agemons>=6971 & agemons<=21899 & _cbmi >= 18.5 & _cbmi <25)
replace dnorm19_59=. if agemons<6971
replace dnorm19_59=. if agemons>21899
replace dnorm19_59=. if _cbmi==.
rename dnorm19_59 T7_i13
*==============================================================================*
* T7_i14. Sobrepeso en adultos de 19 a 59 años de edad
*==============================================================================*
cap drop dspeso19_59 
gen dspeso19_59=0
replace dspeso19_59=100 if (_cbmi!=. & agemons>=6971 & agemons<=21899 & _cbmi >= 25 & _cbmi <30)
replace dspeso19_59=. if agemons<6971
replace dspeso19_59=. if agemons>21899
replace dspeso19_59=. if _cbmi==.
rename dspeso19_59 T7_i14
*==============================================================================*
* T7_i15. Obesidad en adultos de 19 a 59 años de edad
*==============================================================================*
cap drop dobes19_59 
gen dobes19_59=0
replace dobes19_59=100 if (_cbmi!=. & agemons>=6971 & agemons<=21899  & _cbmi >=30)
replace dobes19_59=. if agemons<6971
replace dobes19_59=. if agemons>21899
replace dobes19_59=. if _cbmi==.
rename dobes19_59 T7_i15
*==============================================================================*
* T7_i16. Sobrepeso y obesidad en adultos de 19 a 59 años de edad
*==============================================================================*
cap drop dspobes19_59 
gen dspobes19_59=0
replace dspobes19_59=100 if (_cbmi!=. & agemons>=6971 & agemons<=21899 & _cbmi >= 25)
replace dspobes19_59=. if agemons<6971
replace dspobes19_59=. if agemons>21899
replace dspobes19_59=. if _cbmi==.
rename dspobes19_59 T7_i16
*==============================================================================*
