*==============================================================================*
* TÍTULO DE LA SINTAXIS:													   *
* Fecundidad																   *
* OPERACIÓN ESTADÍSTICA:													   *
* Encuesta Nacional de Salud y Nutrición (ENSANUT - 2018)					   *
*==============================================================================*
* Fecha de elaboración:       10 de Diciembre del 2018					       *
* Fecha última modificación:  19 de Diciembre del 2019				   	   	   *
*==============================================================================*
* Elaborado por:                                                               *
* Instituto Nacional de Estadística y Censos (INEC)							   *
* Link:                                                                        *
* www.ecuadorencifras.gob.ec 												   *
*==============================================================================*

clear all
set more off

* En esta sección se copia la dirección en donde se encuentran las bases de datos
cd "C:\ENSANUT 2018\Bases de datos\Bases_trabajadas"

use 4_BDD_ENS2018_f2_mef, clear 

svyset upm [iw=fexp], strata(estrato) vce(linearized) singleunit(certainty) 

*==============================================================================*
* Imputación de fechas
*==============================================================================*

// EDAD MADRE //

replace f2_s1_100_3 = (fecha_anio - f2_s1_101) if f2_s1_100_3==. 
replace f2_s1_100_2=6 if f2_s1_100_2==. 
replace f2_s1_100_1=15 if f2_s1_100_1==. 

cap drop d_am_bm d_am_entr
gen d_am_bm = f2_s1_100_1/30
replace d_am_bm =1 if d_am_bm>1
gen d_am_entr = fecha_dia/30
replace d_am_entr =1 if d_am_entr>1

gen amd_entr = ( fecha_anio - 1900 )*12 + fecha_mes + d_am_entr
lab var amd_entr "anios meses con dia entrevista"

gen amd_nacmad = (f2_s1_100_3 - 1900)*12 + f2_s1_100_2 + d_am_bm
lab var amd_nacmad "anios-meses-dia nacimiento madre"

// EDAD HIJOS //

forvalues x=1/10 {

replace f2_s2_218_`x'_b1=15 if f2_s2_218_`x'_b1==88
replace f2_s2_218_`x'_b2=6 if f2_s2_218_`x'_b2==88
replace f2_s2_218_`x'_b3=. if f2_s2_218_`x'_b3==8888
replace f2_s2_218_`x'_d1 = . if f2_s2_218_`x'_d1==88
gen anio_hijo`x' = (fecha_anio - f2_s2_218_`x'_d1)
replace f2_s2_218_`x'_b3 = anio_hijo`x' if f2_s2_218_`x'_b3==.
gen d_am_b`x' = f2_s2_218_`x'_b1/30
replace d_am_b`x' = 1 if d_am_b`x'>1
gen nacim_`x' = ( f2_s2_218_`x'_b3 - 1900 )*12 + f2_s2_218_`x'_b2 + d_am_b`x'
lab var nacim_`x' "anios meses con dia nacimiento `x' hijo "
}
replace nacim_2 = (nacim_1 + nacim_3)/2 if nacim_2==.
replace nacim_3 = (nacim_2 + nacim_4)/2 if nacim_3==.
replace nacim_4 = (nacim_3 + nacim_5)/2 if nacim_4==.
replace nacim_5 = (nacim_4 + nacim_6)/2 if nacim_5==.
replace nacim_6 = (nacim_5 + nacim_7)/2 if nacim_6==.
replace nacim_7 = (nacim_6 + nacim_8)/2 if nacim_7==.
replace nacim_8 = (nacim_7 + nacim_9)/2 if nacim_8==.
replace nacim_9 = (nacim_8 + nacim_10)/2 if nacim_9==.

*==============================================================================*
* T9_i1. Tasa global y específica de fecundidad (periodo 5 años)
*==============================================================================*

tfr2 [pweight=fexp], bvar(nacim_*) dates(amd_entr) ///
wbirth(amd_nacmad) ageg(5) cluster(upm) len(5)  

by area, sort: tfr2 [pweight=fexp], bvar(nacim_*) dates(amd_entr) ///
wbirth(amd_nacmad) ageg(5) cluster(upm) len(5) 

*==============================================================================*


