*==============================================================================*
* TÍTULO DE LA SINTAXIS:													   *
* Fecundidad																   *
* OPERACIÓN ESTADÍSTICA:													   *
* Encuesta Nacional de Salud y Nutrición (ENSANUT - 2018)					   *
*==============================================================================*
* Fecha de elaboración:       10 de Diciembre del 2018					       *
* Fecha última modificación:  19 de Diciembre del 2019				   	   	   *
*==============================================================================*
* Elaborado por:                                                               *
* Instituto Nacional de Estadística y Censos (INEC)							   *
* Link:                                                                        *
* www.ecuadorencifras.gob.ec 												   *
*==============================================================================*

clear all
set more off
* En esta sección se copia la dirección en donde se encuentran las bases de datos
cd "C:\ENSANUT 2018\Bases de datos\Bases_trabajadas"

use 4_BDD_ENS2018_f2_mef, clear 

svyset upm [iw=fexp], strata(estrato) vce(linearized) singleunit(certainty) 

*==============================================================================*
* Imputación de fechas
*==============================================================================*

// EDAD MADRE //

replace f2_s1_100_3 = (fecha_anio - f2_s1_101) if f2_s1_100_3==. 
replace f2_s1_100_2=6 if f2_s1_100_2==. 
replace f2_s1_100_1=15 if f2_s1_100_1==. 

cap drop d_am_bm d_am_entr
gen d_am_bm = f2_s1_100_1/30
replace d_am_bm =1 if d_am_bm>1
gen d_am_entr = fecha_dia/30
replace d_am_entr =1 if d_am_entr>1

gen amd_entr = ( fecha_anio - 1900 )*12 + fecha_mes + d_am_entr
lab var amd_entr "anios meses con dia entrevista"

gen amd_nacmad = (f2_s1_100_3 - 1900)*12 + f2_s1_100_2 + d_am_bm
lab var amd_nacmad "anios-meses-dia nacimiento madre"

// EDAD HIJOS //

forvalues x=1/10 {

replace f2_s2_218_`x'_b1=15 if f2_s2_218_`x'_b1==88
replace f2_s2_218_`x'_b2=6 if f2_s2_218_`x'_b2==88
replace f2_s2_218_`x'_b3=. if f2_s2_218_`x'_b3==8888
replace f2_s2_218_`x'_d1 = . if f2_s2_218_`x'_d1==88
gen anio_hijo`x' = (fecha_anio - f2_s2_218_`x'_d1)
replace f2_s2_218_`x'_b3 = anio_hijo`x' if f2_s2_218_`x'_b3==.
gen d_am_b`x' = f2_s2_218_`x'_b1/30
replace d_am_b`x' = 1 if d_am_b`x'>1
gen nacim_`x' = ( f2_s2_218_`x'_b3 - 1900 )*12 + f2_s2_218_`x'_b2 + d_am_b`x'
lab var nacim_`x' "anios meses con dia nacimiento `x' hijo "
}
replace nacim_2 = (nacim_1 + nacim_3)/2 if nacim_2==.
replace nacim_3 = (nacim_2 + nacim_4)/2 if nacim_3==.
replace nacim_4 = (nacim_3 + nacim_5)/2 if nacim_4==.
replace nacim_5 = (nacim_4 + nacim_6)/2 if nacim_5==.
replace nacim_6 = (nacim_5 + nacim_7)/2 if nacim_6==.
replace nacim_7 = (nacim_6 + nacim_8)/2 if nacim_7==.
replace nacim_8 = (nacim_7 + nacim_9)/2 if nacim_8==.
replace nacim_9 = (nacim_8 + nacim_10)/2 if nacim_9==.

*==============================================================================*
* T9_i2. Edad promedio en la primera relación sexual
*==============================================================================*

cap drop edadpro 
clonevar edadpro = f2_s8_804 if f2_s8_802==1 | f2_s8_802==2 
replace edadpro = 77 if edadpro==99
replace edadpro = 77 if f2_s8_803==3
replace edadpro = 99 if f2_s8_803==2 
replace edadpro = f2_s8_831 if edadpro==. & f2_s8_802==3

cap drop T9_i2
gen T9_i2 = edadpro if edadpro!=77 & edadpro!=88 & edadpro!=99 
tab T9_i2 
mean T9_i2

*==============================================================================*
* T9_i3. Edad promedio en la primera unión
*==============================================================================*

gen 	edadpriuni = f2_s9_905
replace edadpriuni=. if (edadpriuni==77)
replace edadpriuni=. if f2_s9_900==7 & f2_s9_901==2 & f2_s9_905!=.
rename edadpriuni T9_i3
tab T9_i3
mean T9_i3

*==============================================================================*
* T9_i4. Edad promedio al primer nacimiento
*==============================================================================*
* CMC - Nacimiento de la madre
gen madre_cmc = 12*f2_s1_100_3 + f2_s1_100_2

* Mes y año del primer nacimiento (fb: first birth)
gen fbmes=.
gen fbano=.
forvalues i = 1/10 {
replace f2_s2_218_`i'_b3=8888 if f2_s2_218_`i'_b3==88 
replace fbmes = f2_s2_218_`i'_b2 if (f2_s2_217_4==`i')
replace fbano = f2_s2_218_`i'_b3 if (f2_s2_217_4==`i')
}
* Diferencia entre año de nacimiento de la madre y de su primer(a) hijo(a)
gen dif = fbano - f2_s1_100_3 if fbano!=8888
tab dif

* CMC - Nacimiento de primer(a) hijo(a)
gen 	phijo_cmc = 12*fbano + fbmes if dif>10 & (fbmes!=. & fbmes!=88)
replace phijo_cmc = 12*fbano + 6     if dif>10 & (fbmes==. | fbmes==88) // Imputación

* Edad al primer nacimiento (fbage: first birth age)
gen 	fbage = . if (f2_s2_217_4==0 | f2_s2_217_4==.)
replace fbage = int((phijo_cmc - madre_cmc)/12) if (fbano<=2019)
replace fbage = . if (dif<10) | (f2_s1_100_2==88 & f2_s1_100_3==8888)

rename fbage T9_i4
tab T9_i4
mean T9_i4



