*==============================================================================*
* TÍTULO DE LA SINTAXIS:													   *
* Fecundidad																   *
* OPERACIÓN ESTADÍSTICA:													   *
* Encuesta Nacional de Salud y Nutrición (ENSANUT - 2018)					   *
*==============================================================================*
* Fecha de elaboración:       10 de Diciembre del 2018					       *
* Fecha última modificación:  19 de Diciembre del 2019				   	   	   *
*==============================================================================*
* Elaborado por:                                                               *
* Instituto Nacional de Estadística y Censos (INEC)							   *
* Link:                                                                        *
* www.ecuadorencifras.gob.ec 												   *
*==============================================================================*

clear all
set more off
* En esta sección se copia la dirección en donde se encuentran las bases de datos
cd "C:\ENSANUT 2018\Bases de datos\Bases_trabajadas"

use 1_BDD_ENS2018_f1_personas, clear 
rename id_per id_hijo
keep id_hijo area prov region etnia nbi_1 edaddias
tempfile base_per
save `base_per', replace

use 4_BDD_ENS2018_f2_mef, clear 
keep id_per f2_s1_10* fecha_* fexp estrato upm 
tempfile base_mef
save `base_mef', replace 

use 4_BDD_ENS2018_f2_mef, clear 
keep id* f2_s2_218_*_1 f2_s2_218_*_a f2_s2_218_*_b* f2_s2_218_*_d*   

rename f2_s2_218_*_1  f2_s2_218_1_* 
rename f2_s2_218_*_a  f2_s2_218_a_*
rename f2_s2_218_*_b1 f2_s2_218_b1_*  
rename f2_s2_218_*_b2 f2_s2_218_b2_*  
rename f2_s2_218_*_b3 f2_s2_218_b3_* 
rename f2_s2_218_*_d1 f2_s2_218_d1_* 
rename f2_s2_218_*_d2 f2_s2_218_d2_* 

gen id_ma = _n
reshape long f2_s2_218_1_ f2_s2_218_a_ ///
f2_s2_218_b1_ f2_s2_218_b2_ f2_s2_218_b3_ ///
f2_s2_218_d1_ f2_s2_218_d2_ , i(id_ma) j(id_nin) 

rename f2_s2_218_a_ sexo  

*==============================================================================*
* Generación del identificador del hijo
*==============================================================================*
qui foreach var of varlist f2_s2_218_1_{
tempvar largo
tostring `var', replace force
gen `largo'=length(`var')
sum `largo'
replace `var'=substr(string(10^(r(max)-`largo')),2,.)+`var' if r(max)>`largo'
drop `largo'
}
*
egen id_hijo    =concat(id_hogar f2_s2_218_1_)
egen id_hijo_ord=concat(id_per f2_s2_218_1_ id_nin)
label var id_hijo "Identificador del hijo"
label var id_hijo_ord "Identificador del hijo según el orden"

*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
*Se valida los códigos de los hijos  
replace id_hijo_ord = "" if f2_s2_218_1_=="0." | f2_s2_218_1_=="00" 
*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

*Mantengo la base de los hijos 
keep if id_hijo_ord!=""

merge m:1 id_per using `base_mef' 
keep if _merge==3
drop _merge

merge m:1 id_hijo using `base_per' 
keep if _merge==3 | _merge==1 
drop _merge

svyset upm [iw=fexp], strata(estrato) vce(linearized) singleunit(certainty) 

*==============================================================================*
* Imputación de fechas
*==============================================================================*

// EDAD MADRE //

replace f2_s1_100_3 = (fecha_anio - f2_s1_101) if f2_s1_100_3==. 
replace f2_s1_100_2=6 if f2_s1_100_2==. 
replace f2_s1_100_1=15 if f2_s1_100_1==. 

cap drop d_am_bm d_am_entr
gen d_am_bm = f2_s1_100_1/30
replace d_am_bm =1 if d_am_bm>1
gen d_am_entr = fecha_dia/30
replace d_am_entr =1 if d_am_entr>1

gen amd_entr = ( fecha_anio - 1900 )*12 + fecha_mes + d_am_entr
lab var amd_entr "anios meses con dia entrevista"

gen amd_nacmad = (f2_s1_100_3 - 1900)*12 + f2_s1_100_2 + d_am_bm
lab var amd_nacmad "anios-meses-dia nacimiento madre"

// EDAD HIJOS //

replace f2_s2_218_b1_=15 if f2_s2_218_b1_==88
replace f2_s2_218_b2_=6 if f2_s2_218_b2_==88
replace f2_s2_218_b3_=. if f2_s2_218_b3_==8888
replace f2_s2_218_d1_ = . if f2_s2_218_d1_==88
gen anio_hijo = (fecha_anio - f2_s2_218_d1_)
replace f2_s2_218_b3_ = anio_hijo if f2_s2_218_b3_==.
gen d_am_b = f2_s2_218_b1_/30
replace d_am_b = 1 if d_am_b>1
gen nacim = ( f2_s2_218_b3_ - 1900 )*12 + f2_s2_218_b2_ + d_am_b
lab var nacim "anios meses con dia nacimiento hijo"

sort id_ma id_ni

by id_ma: gen nacim_1 = (nacim[_n-1] + nacim[_n+1])/2 if nacim[_n]==.
replace nacim=nacim_1 if nacim==. & nacim_1!=. 

*==============================================================================*
* T9_i5. Espaciamiento entre nacimientos
*==============================================================================*

*** Intervalo del nacimiento anterior

gsort id_ma -id_ni

cap drop intp 
by id_ma: gen intp = nacim[_n] - nacim[_n-1]
replace intp = . if f2_s2_218_b3_==8888 | f2_s2_218_b3_==88 
replace intp = . if edaddias>1826  

rename intp T9_i5

svy: mean T9_i5 

